female_prefix = [
    "að",
    "alfr",
    "arn",
    "asa",
    "astr",
    "aud",
    "berg",
    "bor",
    "brun",
    "dagn",
    "eir",
    "ek",
    "fre",
    "frid",
    "geir",
    "gjo",
    "gud",
    "gyð",
    "haf",
    "halla",
    "hel",
    "her",
    "hild",
    "ing",
    "kat",
    "kel",
    "liv",
    "magn",
    "ny",
    "od",
    "rau",
    "sig",
    "siv",
    "skul",
    "svanh",
    "thor",
    "tor",
    "ulv",
    "val",
    "yngv",
]

female_suffix = [
    "a",
    "dis",
    "dís",
    "frid",
    "fríð",
    "gerðr",
    "gjerd",
    "gunn",
    "gyða",
    "hildr",
    "lif",
    "líf",
    "run",
    "rún",
    "sol",
    "sól",
    "tora",
    "þora",
    "vor",
    "vör",
]

male_prefix = [
    "arn",
    "bal",
    "bjorn",
    "dar",
    "ein",
    "erik",
    "fre",
    "grim",
    "gunn",
    "hakon",
    "har",
    "ing",
    "ivar",
    "leif",
    "magnus",
    "odin",
    "olaf",
    "rag",
    "sig",
    "sven",
    "thor",
    "ulf",
    "vald",
    "vik",
    "wul",
]

male_suffix = [
    "ald",
    "ar",
    "bard",
    "bjorn",
    "brand",
    "dor",
    "end",
    "fred",
    "gard",
    "grim",
    "hak",
    "hart",
    "kel",
    "laf",
    "mar",
    "olf",
    "rak",
    "rik",
    "run",
    "stein",
    "thor",
    "ulf",
    "vald",
    "var",
    "vik",
    "yng",
]

surname_prefix = [
    "arn",
    "as",
    "bal",
    "ber",
    "dag",
    "ein",
    "erl",
    "fro",
    "gar",
    "hak",
    "ing",
    "jar",
    "kar",
    "lif",
    "magn",
    "nor",
    "od",
    "ragn",
    "sig",
    "thor",
    "ulf",
    "val",
    "yng",
]

surname_suffix = [
    "brand",
    "dottir",
    "fjord",
    "grim",
    "hald",
    "ing",
    "jord",
    "karl",
    "lief",
    "mann",
    "nor",
    "olfr",
    "rav",
    "sif",
    "skar",
    "son",
    "ulf",
    "vald",
    "wulf",
    "yr",
]

female_names = [
    "Aesa",
    "Agatha",
    "Ailith",
    "Aldis",
    "Alfhild",
    "Alfhildr",
    "Alva",
    "Arnbjorg",
    "Asa",
    "Asgunna",
    "Aslog",
    "Astrid",
    "Astrida",
    "Auda",
    "Audhildr",
    "Birgit",
    "Birna",
    "Bjorg",
    "Bodil",
    "Boedicia",
    "Borg",
    "Borghild",
    "Borghildr",
    "Borgrun",
    "Botulfr",
    "Brenn",
    "Brenna",
    "Brura",
    "Brynhildr",
    "Brynju",
    "Dagmar",
    "Dagn",
    "Dagney",
    "Dagni",
    "Dagny",
    "Dagný",
    "Dagr",
    "Dagrun",
    "Dagrún",
    "Dofa",
    "Dor",
    "Dárgud",
    "Edda",
    "Edith",
    "Eilif",
    "Eimyrja",
    "Eira",
    "Eirik",
    "Eirika",
    "Eiriksdóttir",
    "Eirny",
    "Eirífa",
    "Eivor",
    "Eldhildr",
    "Eldin",
    "Eldrid",
    "Eldrida",
    "Elin",
    "Estrid",
    "Freya",
    "Freybjorg",
    "Freyda",
    "Freydis",
    "Freylaug",
    "Frida",
    "Fridleif",
    "Fridleva",
    "Fridri",
    "Fridrika",
    "Fridu",
    "Friduna",
    "Frigg",
    "Friggja",
    "Frostina",
    "Fríða",
    "Gerd",
    "Gerda",
    "Gertrúd",
    "Gillaug",
    "Gim",
    "Gin",
    "Gingn",
    "Gio",
    "Gisela",
    "Gisla",
    "Gisli",
    "Gislin",
    "Gizzur",
    "Gladis",
    "Gunnhild",
    "Gyda",
    "Hedvig",
    "Helena",
    "Helga",
    "Hild",
    "Hilda",
    "Hildegard",
    "Hildegunn",
    "Hilding",
    "Hildrid",
    "Hildrun",
    "Hildulv",
    "Hildur",
    "Hildvaldr",
    "Hildvöl",
    "Hildvölur",
    "Hillevi",
    "Ida",
    "Idun",
    "Idunn",
    "Indrid",
    "Inga",
    "Ingeborg",
    "Ingela",
    "Ingiridh",
    "Ingrid",
    "Ingridh",
    "Ingridr",
    "Ingunn",
    "Iolster",
    "Irén",
    "Iréne",
    "Isolde",
    "Jenna",
    "Jofrid",
    "Jofrida",
    "Jona",
    "Jora",
    "Jorid",
    "Jorund",
    "Jorunn",
    "Josefina",
    "Jovilda",
    "Judith",
    "Julfina",
    "Jurdís",
    "Jurðis",
    "Kara",
    "Kari",
    "Karolina",
    "Katrin",
    "Katriona",
    "Katrín",
    "Kelda",
    "Ketra",
    "Kirsten",
    "Kirsti",
    "Kirstin",
    "Kjara",
    "Klara",
    "Kol",
    "Kolbrun",
    "Kolhilda",
    "Lagertha",
    "Lilja",
    "Linda",
    "Lisbeth",
    "Lise",
    "Lisebet",
    "Lisken",
    "Liva",
    "Livia",
    "Lova",
    "Lovis",
    "Lovisa",
    "Ludvika",
    "Lund",
    "Luthviga",
    "Lína",
    "Líne",
    "Magdalena",
    "Magna",
    "Magnhild",
    "Maren",
    "Margareta",
    "Mathilda",
    "Matilda",
    "Mette",
    "Mildred",
    "Mir",
    "Mist",
    "Mjoll",
    "Mojeda",
    "Morrí",
    "Märta",
    "Míldi",
    "Móri",
    "Nanna",
    "Natt",
    "Ninna",
    "Njord",
    "Nora",
    "Norse",
    "Norsea",
    "Nott",
    "Nyda",
    "Nypa",
    "Nyre",
    "Närve",
    "Nína",
    "Nönn",
    "Olga",
    "Ragna",
    "Ragnhild",
    "Ragnhildr",
    "Ragnild",
    "Ranna",
    "Rannvei",
    "Ranveig",
    "Rauth",
    "Rikissa",
    "Rána",
    "Ráðúlfr",
    "Rú",
    "Rúnfrid",
    "Rúnfrí",
    "Rúnh",
    "Rúnhi",
    "Sighild",
    "Sigmund",
    "Signe",
    "Signy",
    "Signý",
    "Sigr",
    "Sigrhildr",
    "Sigrid",
    "Sigridr",
    "Sigrun",
    "Sigryn",
    "Sigrö",
    "Sigrún",
    "Thora",
    "Thordis",
    "Thorfinna",
    "Thorgunna",
    "Thorgunnr",
    "Thornunna",
    "Thurid",
    "Thy",
    "Thyra",
    "Thyri",
    "Thyrs",
    "Tora",
    "Torborg",
    "Tove",
    "Tyra",
    "Ulfhild",
    "Una",
    "Unn",
    "Unnr",
    "Urania",
    "Urd",
    "Urdis",
    "Urdul",
    "Ursula",
    "Urta",
    "Urtla",
    "Urðr",
    "Valdis",
    "Valkyrie",
    "Vigdis",
    "Vigrid",
    "Vigunn",
    "Vilda",
    "Vilde",
    "Vilja",
    "Villgjerd",
    "Vilvei",
    "Vilveig",
    "Vindura",
    "Vinga",
    "Vivianne",
    "Völvina",
    "Ylfa",
    "Ylva",
    "Yngvild",
    "Yngvilda",
    "Yngvildr",
    "Yrsa",
    "Yrse",
    "Yrsel",
    "Yrtt",
    "Yrttt",
    "Yrtu",
    "Yrug",
    "Yvette",
    "Ása",
    "Åsa",
]

male_names = [
    "Agnar",
    "Agni",
    "Aki",
    "Alaric",
    "Alf",
    "Alfgeir",
    "Alrik",
    "Alvar",
    "Amund",
    "Ansgar",
    "Anund",
    "Arne",
    "Arngrim",
    "Arnulf",
    "Arvid",
    "Asbjorn",
    "Asbjørn",
    "Asgeir",
    "Asger",
    "Askold",
    "Aslak",
    "Astrid",
    "Balder",
    "Bengt",
    "Bernt",
    "Bertram",
    "Birger",
    "Birk",
    "Bjarte",
    "Bjorn",
    "Bo",
    "Bragi",
    "Brand",
    "Brandr",
    "Dag",
    "Dagfinn",
    "Dagur",
    "Dan",
    "Egil",
    "Eilif",
    "Einar",
    "Eindride",
    "Eirik",
    "Erik",
    "Erikur",
    "Erlend",
    "Erling",
    "Eyvind",
    "Finn",
    "Folke",
    "Frej",
    "Freybjorn",
    "Freyr",
    "Fridolf",
    "Frode",
    "Gardar",
    "Gisli",
    "Gizur",
    "Gorm",
    "Gudmund",
    "Gunder",
    "Gunnar",
    "Gustav",
    "Hakon",
    "Halfdan",
    "Halfred",
    "Halldor",
    "Hallvard",
    "Halvar",
    "Halvdan",
    "Harald",
    "Havard",
    "Helgi",
    "Hemming",
    "Henrik",
    "Hjalmar",
    "Holger",
    "Hrolf",
    "Inge",
    "Ingimund",
    "Ingvar",
    "Isak",
    "Ivar",
    "Ivarr",
    "Jari",
    "Jarl",
    "Jofrid",
    "Johan",
    "Karl",
    "Ketil",
    "Ketill",
    "Kjartan",
    "Kjell",
    "Knut",
    "Kolbein",
    "Kolli",
    "Lars",
    "Lasse",
    "Leif",
    "Ljot",
    "Loki",
    "Magnar",
    "Magne",
    "Magnus",
    "Malmfrid",
    "Mikkel",
    "Njal",
    "Njord",
    "Njål",
    "Nordal",
    "Odd",
    "Oddbjorn",
    "Oddgeir",
    "Odin",
    "Olaf",
    "Ormr",
    "Orvar",
    "Orvarr",
    "Osvald",
    "Ragnar",
    "Ragnarr",
    "Ragnvald",
    "Rane",
    "Ravn",
    "Reidar",
    "Roald",
    "Rolf",
    "Runar",
    "Sigbjorn",
    "Sigfast",
    "Sigfred",
    "Sigurd",
    "Sigvald",
    "Sigvard",
    "Sigvid",
    "Sivert",
    "Stefan",
    "Stein",
    "Steinar",
    "Sten",
    "Stig",
    "Styr",
    "Styrbiorn",
    "Svein",
    "Sveinn",
    "Sven",
    "Svend",
    "Sverre",
    "Thor",
    "Thorbjorn",
    "Thorbjornr",
    "Thorbjørn",
    "Thorey",
    "Thorleif",
    "Thorvald",
    "Tobias",
    "Torbjorn",
    "Tore",
    "Torfinn",
    "Torger",
    "Torgny",
    "Torkel",
    "Torsten",
    "Trygve",
    "Ulf",
    "Ulfar",
    "Ulfhedin",
    "Ulrik",
    "Ulv",
    "Valdemar",
    "Vidar",
    "Viggo",
    "Viking",
    "Vilhelm",
    "Wilhelm",
    "Yngvar",
    "Yngvarr",
    "Yngve",
    "Åke",
    "Åsgeir",
    "Åsgeirr",
    "Åsmund",
    "Åsmundr",
    "Åsmundur",
    "Åvald",
    "Örjan",
    "Örn",
    "Örnolf",
    "Ørjan",
    "Ørn",
    "Ørnulf",
    "Ørvar",
    "Øystein",
    "Øyvind",
]

female_surnames = [
    "Aesirsdottir",
    "Alvisdottir",
    "Arngrimmsdottir",
    "Asvaldsdottir",
    "Audunsdottir",
    "Bjarnardottir",
    "Bragisdottir",
    "Egilssdottir",
    "Eiriksdottir",
    "Eyvindsdottir",
    "Finnbjarnardottir",
    "Flosadottir",
    "Freysteinsdottir",
    "Geirsdottir",
    "Gisladottir",
    "Grimhildrsdottir",
    "Gudmundsdottir",
    "Gunnarsdottir",
    "Hakonardottir",
    "Halfdanardottir",
    "Hallbergsdottir",
    "Halldorsdottir",
    "Halvdansdottir",
    "Havardsdottir",
    "Helgadottir",
    "Herjolfsdottir",
    "Hognisdottir",
    "Hrolfsdottir",
    "Hunbogadottir",
    "Ingibjorgsdottir",
    "Ingolfsdottir",
    "Jokulsdottir",
    "Ketilsdottir",
    "Kolbeinsdottir",
    "Kormakrsdottir",
    "Leifsdottir",
    "Magnusdottir",
    "Njalsdottir",
    "Oddsdottir",
    "Olafsdottir",
    "Ottarsdottir",
    "Ragnarsdottir",
    "Reynisdottir",
    "Rolfssdottir",
    "Sigmundsdottir",
    "Sigurdsdottir",
    "Skardisdottir",
    "Skarphedinsdottir",
    "Snaedisdottir",
    "Sokkvisdottir",
    "Steinsdottir",
    "Sturlungsdottir",
    "Svavasdottir",
    "Thorbjorgsdottir",
    "Thordissdottir",
    "Thorkelsdottir",
    "Thorleifsdottir",
    "Thormodrsdottir",
    "Thornsdottir",
    "Thorsdottir",
    "Thorvaldsdottir",
    "Torfelsdottir",
    "Torvaldsdottir",
    "Valgardrsdottir",
    "Valgeirsdottir",
    "Vigdisdottir",
    "Vigfusdottir",
    "Viggeirsdottir",
    "Vigiliasdottir",
    "Vigmundsdottir",
    "Vikarsdottir",
    "Vikingrsdottir",
    "Viktoriasdottir",
    "Viktorrsdottir",
    "Vilhjalmrsdottir",
    "Vioarrsdottir",
    "Vordrsdottir",
    "Yngvadottir",
    "Yngvildrsdottir",
    "Yngvisdottir",
    "Yrsadottir",
    "Yrsaelsdottir",
    "Yrungsdottir",
    "Yvaedsdottir",
    "Yvaegisdottir",
    "Yvaegsdottir",
    "Yvaelisdottir",
    "Yvaesnddottir",
    "Yvaesndldottir",
    "Yvaesndnndottir",
    "Yvaesndnrdottir",
    "Yvaesndrdottir",
    "Yvaesndstdottir",
    "Yvaesnndottir",
    "Yvaesnrdottir",
    "Yvaesstdottir",
    "Yvaestdottir",
    "Yvaestldottir",
    "Yvaestndottir",
    "Yvaestrdottir",
    "Yvaetdottir",
    "Yvaethrdottir",
    "Yvaggisdottir",
    "Yvaggisrdottir",
    "Yvagndottir",
    "Yvaiwddottir",
    "Yvaletdottir",
    "Yvalsdottir",
    "Yvawddottir",
    "Yveasandottir",
    "Yveasndottir",
    "Yvedsdottir",
    "Yvessdottir",
    "Yvethsdottir",
    "Yvettesdottir",
    "Yvonnisdottir",
    "Yvorisdottir",
    "Yvundisdottir",
    "Ywainadottir",
    "Ywettesdottir",
    "Ywisdsdottir",
    "Ywishdottir",
]

male_surnames = [
    "Aesirsson",
    "Alfsson",
    "Arnbjornsson",
    "Asgeirsson",
    "Asgotsson",
    "Askellsson",
    "Astridsson",
    "Baldursson",
    "Bjornsson",
    "Dagsson",
    "Egilsson",
    "Einarsson",
    "Eiriksson",
    "Erlendsson",
    "Eyvindsson",
    "Finnsson",
    "Freysson",
    "Gunnarsson",
    "Gunnlaugsson",
    "Guthormsson",
    "Halfdanarson",
    "Halfdansson",
    "Halfreksson",
    "Halvardsson",
    "Haraldsson",
    "Hasteinsson",
    "Hauksson",
    "Helgeirsson",
    "Helgisson",
    "Hemmingsson",
    "Hjalmarsson",
    "Hjortsson",
    "Holmgeirsson",
    "Ingesson",
    "Ivarsson",
    "Jarlsson",
    "Ketilsson",
    "Kolbeinsson",
    "Leifrsson",
    "Magnusson",
    "Njallsson",
    "Odinsson",
    "Olafsson",
    "Ottarsson",
    "Ragnarisson",
    "Ragnarsson",
    "Rolfsson",
    "Siegfriedsson",
    "Sigurdsson",
    "Snorresson",
    "Stefansson",
    "Steinsson",
    "Svennson",
    "Thorbjornsson",
    "Thorfinnsson",
    "Thorgestsson",
    "Thorgilsson",
    "Thorisson",
    "Thorkellsson",
    "Torolfsson",
    "Tryggvason",
    "Ulfarsson",
    "Ulriksson",
    "Valgardsson",
    "Vigfusson",
    "Viggothsson",
    "Vikingsson",
    "Vilhjalmsson",
    "Yngvarsson",
    "Yngvason",
    "Yngvesson",
    "Yrsaardsson",
    "Yrthardsson",
    "Yrvingsson",
    "Ysbrandsson",
    "Ysgrimsson",
    "Ysmundsson",
    "Ysriksson",
    "Ysulfsson",
    "Yvarsson",
    "Yvarthsson",
    "Yvborgsson",
    "Yvdorsson",
    "Yveriksson",
    "Yvfinnsson",
    "Yvfinsson",
    "Yvfrostsson",
    "Yvgardsson",
    "Yvgarthsson",
    "Yvgeirsson",
    "Yvggvinsson",
    "Yvgiannsson",
    "Yvgilmundsson",
    "Yvgjaldsson",
    "Yvgmundsson",
    "Yvgormsson",
    "Yvgrimmsson",
    "Yvgrimsson",
    "Yvhallsson",
    "Yvhildsson",
    "Yvindsson",
    "Yviriksson",
    "Yvjarthsson",
    "Yvkarsson",
    "Yvkeirsson",
    "Yvkelsson",
    "Yvlafsson",
    "Yvmarsson",
    "Yvmirsson",
    "Yvmundsson",
    "Yvnarsson",
    "Yvneriksson",
    "Yvngirsson",
    "Yvnilsson",
    "Yvningsson",
    "Yvnoriksson",
    "Yvnyrdsson",
    "Yvolgsson",
    "Yvonarsson",
    "Yvoresson",
    "Yvoriksson",
    "Yvormundsson",
    "Yvrageirsson",
    "Yvraldsson",
    "Yvreksson",
    "Yvrikksson",
    "Yvriksson",
    "Yvrimsson",
    "Yvroddsson",
    "Yvroldsson",
    "Yvsarsson",
    "Yvsbornsson",
    "Yvsdottir",
    "Yvseliasson",
    "Yvseriksson",
    "Yvsfredsson",
    "Yvsgeirsson",
    "Yvsgerdsson",
    "Yvsgrimsson",
    "Yvssifsson",
    "Yvsson",
    "Yvstafsson",
    "Yvsteinnsson",
    "Yvsursson",
    "Yvsvaldsson",
    "Yvthorisson",
    "Yvthorsson",
    "Yvtliasson",
    "Yvtrafsson",
    "Yvulfsson",
    "Yvulsson",
    "Yvulviksson",
    "Yvunsson",
    "Yvuriksson",
    "Yvwaldsson",
    "Yvythorsson",
]



female_names = [
    "Abigail",
    "Ada",
    "Adaline",
    "Adelaide",
    "Adeline",
    "Agatha",
    "Agnes",
    "Alberta",
    "Alexandria",
    "Althea",
    "Amaryllis",
    "Amelia",
    "Antoinette",
    "Arabella",
    "Astrid",
    "Augusta",
    "Aurelia",
    "Aurora",
    "Beatrice",
    "Bianca",
    "Calista",
    "Camilla",
    "Cecilia",
    "Celeste",
    "Charlotte",
    "Clara",
    "Clarissa",
    "Clementine",
    "Constance",
    "Cordelia",
    "Corinne",
    "Dahlia",
    "Daisy",
    "Daphne",
    "Delilah",
    "Dorothea",
    "Edith",
    "Eleanor",
    "Eliza",
    "Eloise",
    "Emmeline",
    "Estella",
    "Eugenia",
    "Euphemia",
    "Evangeline",
    "Faye",
    "Felicity",
    "Fern",
    "Fiona",
    "Florence",
    "Freya",
    "Geneva",
    "Genevieve",
    "Georgiana",
    "Ginevra",
    "Giselle",
    "Guinevere",
    "Gwendolyn",
    "Harriet",
    "Hazel",
    "Helena",
    "Henrietta",
    "Hermione",
    "Honoria",
    "Imelda",
    "Imogen",
    "Ingrid",
    "Iris",
    "Isadora",
    "Ivy",
    "Josephine",
    "Juniper",
    "Lavinia",
    "Lenora",
    "Lilith",
    "Lillian",
    "Lorelei",
    "Lucinda",
    "Lydia",
    "Mabel",
    "Maeve",
    "Magnolia",
    "Marceline",
    "Mariana",
    "Marigold",
    "Matilda",
    "Millicent",
    "Minerva",
    "Mirabelle",
    "Nora",
    "Octavia",
    "Odette",
    "Olive",
    "Opal",
    "Ophelia",
    "Penelope",
    "Persephone",
    "Philomena",
    "Primrose",
    "Prudence",
    "Rosalind",
    "Rosamund",
    "Rowena",
    "Scarlett",
    "Seraphina",
    "Sophronia",
    "Sylvia",
    "Tabitha",
    "Temperance",
    "Theodora",
    "Valentina",
    "Veronica",
    "Victoria",
    "Viola",
    "Vivienne",
    "Wilhelmina",
    "Winifred",
    "Winona",
    "Zara",
    "Zelda",
    "Zephyrine",
    "Zinnia",
]

male_names = [
    "Alaric",
    "Alastair",
    "Algernon",
    "Ambrose",
    "Archibald",
    "Atticus",
    "Augustus",
    "Balthazar",
    "Barnaby",
    "Bartholomew",
    "Basil",
    "Benedict",
    "Caspian",
    "Cassius",
    "Cecil",
    "Cedric",
    "Clarence",
    "Cornelius",
    "Crispin",
    "Cyrus",
    "Dashiell",
    "Dexter",
    "Dominic",
    "Dorian",
    "Edgar",
    "Edmund",
    "Edric",
    "Edwin",
    "Elias",
    "Ephraim",
    "Everard",
    "Ezekiel",
    "Felix",
    "Ferdinand",
    "Finnegan",
    "Fitzwilliam",
    "Fletcher",
    "Gabriel",
    "Gideon",
    "Godfrey",
    "Gulliver",
    "Hamilton",
    "Harrison",
    "Hawthorne",
    "Horatio",
    "Hugo",
    "Humphrey",
    "Ignatius",
    "Isidore",
    "Jareth",
    "Jasper",
    "Jeremiah",
    "Jonathan",
    "Kendrick",
    "Kingsley",
    "Klaus",
    "Lancaster",
    "Lancelot",
    "Lazarus",
    "Leopold",
    "Lysander",
    "Maverick",
    "Maximilian",
    "Maximus",
    "Milo",
    "Montgomery",
    "Mortimer",
    "Nathaniel",
    "Nero",
    "Neville",
    "Nigel",
    "Oberon",
    "Octavius",
    "Oliver",
    "Orlando",
    "Orson",
    "Percival",
    "Peregrine",
    "Phineas",
    "Quentin",
    "Quilliam",
    "Quincy",
    "Rafferty",
    "Randolph",
    "Raphael",
    "Reginald",
    "Rufus",
    "Rupert",
    "Rutherford",
    "Salvador",
    "Seamus",
    "Sebastian",
    "Silas",
    "Simeon",
    "Sullivan",
    "Thaddeus",
    "Thelonious",
    "Theodore",
    "Tobias",
    "Tristan",
    "Ulrich",
    "Ulysses",
    "Upton",
    "Uriah",
    "Valentine",
    "Vesper",
    "Victor",
    "Virgil",
    "Walter",
    "Wellington",
    "Wesley",
    "Wilbur",
    "Wilfred",
    "Winston",
    "Wolfgang",
    "Xander",
    "Xavier",
    "Yancy",
    "Yardley",
    "Yorick",
    "Zachariah",
    "Zacharias",
    "Zebediah",
    "Zephyr",
    "Zephyrus",
]

surnames = [
    "Ainsworth",
    "Aldington",
    "Aldridge",
    "Archer",
    "Ashburton",
    "Ashcroft",
    "Ashford",
    "Beauchamp",
    "Beaumont",
    "Blackburn",
    "Blackwood",
    "Blakeley",
    "Bradford",
    "Bradshaw",
    "Bromley",
    "Bromsgrove",
    "Buckingham",
    "Carrington",
    "Chadwick",
    "Chamberlain",
    "Chandler",
    "Channing",
    "Charleston",
    "Charlton",
    "Chatham",
    "Chesney",
    "Clarendon",
    "Copperfield",
    "Cromwell",
    "Cunningham",
    "Darcy",
    "Davenport",
    "Drakeford",
    "Dunhill",
    "Dunstan",
    "Ellington",
    "Ellsworth",
    "Everhart",
    "Fairchild",
    "Fairfax",
    "Farnsworth",
    "Fitzgerald",
    "Fitzroy",
    "Fitzwilliam",
    "Grantham",
    "Graves",
    "Gresham",
    "Griffith",
    "Grimm",
    "Hadley",
    "Hammersmith",
    "Hampton",
    "Hargreaves",
    "Harrington",
    "Hartford",
    "Hawkesworth",
    "Hawkswood",
    "Hawksworth",
    "Hawthorne",
    "Hazelwood",
    "Hemingway",
    "Holland",
    "Holliday",
    "Hollingsworth",
    "Holmes",
    "Huntington",
    "Huxley",
    "Huxtable",
    "Kensington",
    "Kingsford",
    "Kingsley",
    "Lancashire",
    "Lancaster",
    "Langdon",
    "Langley",
    "Linden",
    "Livingston",
    "Lockwood",
    "Maitland",
    "Montague",
    "Montgomery",
    "Parrish",
    "Pemberley",
    "Pembroke",
    "Pendleton",
    "Radburn",
    "Radcliffe",
    "Radley",
    "Ramsey",
    "Rutherford",
    "Standish",
    "Stanhope",
    "Stratford",
    "Stratton",
    "Sunderland",
    "Sutherland",
    "Templeton",
    "Tennyson",
    "Thackeray",
    "Thornfield",
    "Wadsworth",
    "Warrick",
    "Warrington",
    "Waverly",
    "Wellington",
    "Wentworth",
    "Weston",
    "Wetherby",
    "Whitfield",
    "Whitlock",
    "Whittington",
    "Whitworth",
    "Wilberforce",
    "Winchester",
    "Windsor",
    "Winslow",
    "Winthorpe",
    "Winthrop",
    "Witherspoon",
    "Wolcott",
    "Worthington",
    "Wycliffe",
]

female_names_lbr = [
    "Abigail",
    "Ada",
    "Adelaide",
    "Agatha",
    "Agnes",
    "Alice",
    "Alma",
    "Amelia",
    "Anastasia",
    "Angelica",
    "Annabel",
    "Annie",
    "Antoinette",
    "Arabella",
    "Aurelia",
    "Aurora",
    "Barbara",
    "Beatrice",
    "Belle",
    "Bernadette",
    "Bertha",
    "Bessie",
    "Bridget",
    "Camilla",
    "Caroline",
    "Cassandra",
    "Catherine",
    "Cecilia",
    "Celia",
    "Charlotte",
    "Clara",
    "Clarissa",
    "Constance",
    "Cora",
    "Cordelia",
    "Cornelia",
    "Daisy",
    "Daphne",
    "Diana",
    "Dorothea",
    "Dorothy",
    "Edith",
    "Edna",
    "Eleanor",
    "Eliza",
    "Elizabeth",
    "Ella",
    "Eloise",
    "Emily",
    "Emma",
    "Emmeline",
    "Enid",
    "Estella",
    "Esther",
    "Ethel",
    "Eugenia",
    "Eunice",
    "Evangeline",
    "Evelyn",
    "Felicity",
    "Fiona",
    "Florence",
    "Frances",
    "Frederica",
    "Gabriella",
    "Genevieve",
    "Georgiana",
    "Geraldine",
    "Gloria",
    "Grace",
    "Gwendoline",
    "Hannah",
    "Harriet",
    "Hazel",
    "Helen",
    "Helena",
    "Henrietta",
    "Honoria",
    "Ida",
    "Imogen",
    "Irene",
    "Isabella",
    "Ivy",
    "Jacqueline",
    "Jane",
    "Janet",
    "Josephine",
    "Joyce",
    "Judith",
    "Julia",
    "Juliana",
    "Juliet",
    "Katherine",
    "Kathleen",
    "Kitty",
    "Laura",
    "Lavinia",
    "Lenora",
    "Leonora",
    "Leticia",
    "Letitia",
    "Lillian",
    "Lorelei",
    "Loretta",
    "Lottie",
    "Louisa",
    "Louise",
    "Lucinda",
    "Lucy",
    "Luna",
    "Lydia",
    "Mabel",
    "Madeline",
    "Mae",
    "Magdalene",
    "Marcella",
    "Margaret",
    "Marianne",
    "Marjorie",
    "Marlene",
    "Martha",
    "Martina",
    "Mary",
    "Mathilda",
    "Matilda",
    "Maud",
    "May",
    "Meredith",
    "Millicent",
    "Miriam",
    "Nadia",
    "Natalia",
    "Nellie",
    "Nicole",
    "Nora",
    "Norah",
    "Octavia",
    "Odette",
    "Olivia",
    "Ophelia",
    "Patricia",
    "Pearl",
    "Peggy",
    "Penelope",
    "Phoebe",
    "Priscilla",
    "Prudence",
    "Rachel",
    "Rebecca",
    "Regina",
    "Rosalind",
    "Rosamund",
    "Rose",
    "Rosemary",
    "Rowena",
    "Ruth",
    "Sabrina",
    "Sarah",
    "Seraphina",
    "Shirley",
    "Sophia",
    "Susannah",
    "Sylvia",
    "Tabitha",
    "Theodora",
    "Theresa",
    "Thomasina",
    "Ursula",
    "Valerie",
    "Verity",
    "Veronica",
    "Victoria",
    "Viola",
    "Violet",
    "Virginia",
    "Vivian",
    "Wendy",
    "Wilhelmina",
    "Winifred",
    "Winona",
    "Yvonne",
    "Zara",
    "Zenobia",
]

male_names_lbr = [
    "Albert",
    "Alfred",
    "Alistair",
    "Archibald",
    "Arthur",
    "Augustus",
    "Benedict",
    "Benjamin",
    "Bertram",
    "Cecil",
    "Charles",
    "Clarence",
    "Clement",
    "Cornelius",
    "Cyril",
    "David",
    "Duncan",
    "Ebenezer",
    "Edgar",
    "Edmund",
    "Edward",
    "Elijah",
    "Ernest",
    "Eugene",
    "Francis",
    "Franklin",
    "Frederick",
    "Gabriel",
    "George",
    "Gilbert",
    "Henry",
    "Herbert",
    "Horatio",
    "Hugo",
    "Ignatius",
    "Isaac",
    "Isaiah",
    "Ivan",
    "Jacob",
    "James",
    "John",
    "Jonathan",
    "Joseph",
    "Julian",
    "Kenneth",
    "Kingsley",
    "Leonard",
    "Leopold",
    "Lionel",
    "Louis",
    "Malcolm",
    "Matthew",
    "Maxwell",
    "Nathaniel",
    "Nicholas",
    "Nigel",
    "Octavius",
    "Oliver",
    "Oscar",
    "Percival",
    "Peter",
    "Phineas",
    "Quentin",
    "Quincy",
    "Raymond",
    "Reginald",
    "Richard",
    "Rupert",
    "Samuel",
    "Sebastian",
    "Silas",
    "Simon",
    "Theodore",
    "Thomas",
    "Timothy",
    "Tristan",
    "Ulric",
    "Ulysses",
    "Valentine",
    "Victor",
    "Vincent",
    "Walter",
    "Wilfred",
    "William",
    "Winston",
    "Xander",
    "Xavier",
    "Zachary",
    "Zebulon",
    "Zephaniah",
]

surnames_lbr = [
    "Abbott",
    "Abercrombie",
    "Ackerley",
    "Ackerly",
    "Allinson",
    "Almeida",
    "Appleby",
    "Aragon",
    "Archer",
    "Avery",
    "Axminster",
    "Baddock",
    "Bagman",
    "Bagnold",
    "Bagshot",
    "Baron",
    "Baruffio",
    "Basil",
    "Bassat",
    "Beedle",
    "Belby",
    "Bell",
    "Benjy",
    "Bertram",
    "Binns",
    "Black",
    "Blane",
    "Bletchley",
    "Blishwick",
    "Bode",
    "Bones",
    "Boot",
    "Borchart",
    "Bosworth",
    "Branstone",
    "Braveheart",
    "Briar",
    "Bridges",
    "Brocklehurst",
    "Broderick",
    "Brown",
    "Brownstone",
    "Bryce",
    "Bulstrode",
    "Buncle",
    "Burbage",
    "Caddock",
    "Caldwell",
    "Camestros",
    "Campbell",
    "Carneirus",
    "Carrow",
    "Cattermole",
    "Cauldwell",
    "Chadwick",
    "Challenger",
    "Chang",
    "Chapman",
    "Chigley",
    "Chittock",
    "Choudhury",
    "Clagge",
    "Clench",
    "Cobb",
    "Cole",
    "Coleman",
    "Colquhoun",
    "Comstock",
    "Coote",
    "Cornfoot",
    "Crabbe",
    "Cragg",
    "Crane",
    "Creevey",
    "Cresswell",
    "Croaker",
    "Croker",
    "Cross",
    "Crouch",
    "Crowdy",
    "Crup",
    "Dankworth",
    "Dawlish",
    "Dearborn",
    "Delacour",
    "Dell",
    "Diggory",
    "Dippet",
    "Dobbs",
    "Dobson",
    "Docherty",
    "Doge",
    "Dolohov",
    "Dorkins",
    "Dornton",
    "Doyle",
    "Dribble",
    "Droslock",
    "Dudley",
    "Dumbledore",
    "Dunbar",
    "Dungworth",
    "Durant",
    "Dursley",
    "Edgecombe",
    "Edmonds",
    "Edwards",
    "Elder",
    "Elias",
    "Ellis",
    "Elphick",
    "Elphinstone",
    "Everard",
    "Farley",
    "Farthing",
    "Fat",
    "Fawcett",
    "Featherstone",
    "Figg",
    "Filch",
    "Finch",
    "Finch-Fletchley",
    "Finnigan",
    "Firenze",
    "Fisher",
    "Fitz",
    "Fitzroy",
    "Fleet",
    "Flint",
    "Fogarty",
    "Foley",
    "Fonseca",
    "Fontaine",
    "Forbisher",
    "Ford",
    "Fortescue",
    "Foster",
    "Foulkes",
    "Fowler",
    "Foy",
    "Fraser",
    "French",
    "Friar",
    "Frump",
    "Fudge",
    "Fuller",
    "Gaia",
    "Galatea",
    "Gambol",
    "Gamp",
    "Gaunt",
    "Gibbon",
    "Gideon",
    "Gilbert",
    "Gillywater",
    "Glanmore",
    "Glanvill",
    "Gleeson",
    "Glover",
    "Gold",
    "Goldstein",
    "Gonville",
    "Gordon",
    "Gormless",
    "Goshawk",
    "Gossamer",
    "Goudge",
    "Goujon",
    "Goyle",
    "Graham",
    "Granger",
    "Grant",
    "Grantham",
    "Graves",
    "Green",
    "Greengrass",
    "Greenleaf",
    "Greenway",
    "Gregory",
    "Grimblehawk",
    "Grimsditch",
    "Grindelwald",
    "Griselda",
    "Grosswort",
    "Grubbly-Plank",
    "Grunnion",
    "Gudgeon",
    "Gudrun",
    "Gumboil",
    "Gwenog",
    "Hagrid",
    "Halifax",
    "Halstead",
    "Hamilton",
    "Hammerhead",
    "Hampshire",
    "Handy",
    "Hargreaves",
    "Harp",
    "Harper",
    "Harris",
    "Harrow",
    "Hart",
    "Hattersley",
    "Haverstock",
    "Hawthorne",
    "Hayes",
    "Haywood",
    "Hazard",
    "Hecklin",
    "Hedges",
    "Hemming",
    "Hermes",
    "Higglebottom",
    "Higgs",
    "Highfield",
    "Hill",
    "Hillyard",
    "Hodson",
    "Hoggett",
    "Hogwarts",
    "Holborne",
    "Hole",
    "Honey",
    "Hooch",
    "Hookum",
    "Hopkins",
    "Hopkirk",
    "Hoppy",
    "Hornby",
    "Hornung",
    "Horton",
    "Humphrey",
    "Hunt",
    "Hunter",
    "Hutchinson",
    "Huxtable",
    "Ibsen",
    "Ichabod",
    "Impett",
    "Inglebee",
    "Inglethorp",
    "Innes",
    "Intosh",
    "Irons",
    "Isaacs",
    "Ivanova",
    "Ives",
    "Jackman",
    "Jackson",
    "Jacobs",
    "Jaffa",
    "Jenkins",
    "Jenks",
    "Jigger",
    "Johnson",
    "Jolli",
    "Jonas",
    "Jones",
    "Jordan",
    "Jorkins",
    "Juggins",
    "Jugson",
    "Junction",
    "Justice",
    "Jynx",
    "Kaino",
    "Kamkar",
    "Kappa",
    "Karkaroff",
    "Kettleburn",
    "Kidd",
    "Kieron",
    "Killough",
    "King",
    "Kingsley",
    "Kingsnorth",
    "Kirke",
    "Kirkegaard",
    "Kneen",
    "Knibbs",
    "Knott",
    "Knottingley",
    "Knowe",
    "Kramer",
    "Kray",
    "Krum",
    "Krumb",
    "Lacewing",
    "Lackaday",
    "Lancaster",
    "Landsman",
    "Langley",
    "Larkin",
    "LeFevre",
    "Leander",
    "Leek",
    "Leigh",
    "Leitman",
    "Lemon",
    "Lestrange",
    "Levenstein",
    "Levesque",
    "Liddell",
    "Limpet",
    "Littlehales",
    "Lively",
    "Llewellyn",
    "Llewelyn",
    "Lloyd",
    "Lockhart",
    "Lodge",
    "Logan",
    "Long",
    "Longbottom",
    "Longstaff",
    "Lovegood",
    "Lovegrove",
    "Lovett",
    "Lu",
    "Ludovic",
    "Lugwort",
    "Lumby",
    "Lupin",
    "Lupus",
    "Luther",
    "Lynch",
    "Mac",
    "MacAvoy",
    "MacBain",
    "MacBoon",
    "MacCarthy",
    "MacDougal",
    "MacDuff",
    "MacFusty",
    "MacGuffin",
    "MacGuffock",
    "MacHine",
    "MacKinnon",
    "MacKleduff",
    "MacNair",
    "MacNally",
    "MacPherson",
    "MacRory",
    "MacTavish",
    "MacVicar",
    "MacWhirter",
    "Macdonald",
    "Macmillan",
    "Macready",
    "Madam",
    "Madley",
    "Malfoy",
    "Malkin",
    "Mallory",
    "Malone",
    "Mambo",
    "Manco",
    "Manx",
    "March",
    "Marchbanks",
    "Marchmon",
    "Marge",
    "Marples",
    "Mars",
    "Marsh",
    "Marshbanks",
    "Marsland",
    "Martian",
    "Mascarenas",
    "Mason",
    "Maxime",
    "McAllister",
    "McAuley",
    "McBride",
    "McCafferty",
    "McCain",
    "McCann",
    "McClary",
    "McCluck",
    "McCluskey",
    "McCollum",
    "McCorquodale",
    "McCrae",
    "McCullen",
    "McCullough",
    "McDaid",
    "McDermott",
    "McDonald",
    "McDougal",
    "McDowell",
    "McElhinney",
    "McElligott",
    "McEvoy",
    "McFadden",
    "McFarlane",
    "McGarrigle",
    "McGinty",
    "McGonagall",
    "McGrath",
    "McGraw",
    "McGregor",
    "McGuinness",
    "McGuire",
    "McIntosh",
    "McKay",
    "McKechnie",
    "McKendrick",
    "McKenzie",
    "McKeown",
    "McKerrell",
    "McKinney",
    "McLaggen",
    "McLaren",
    "McLaughlin",
    "McLaurin",
    "McLeish",
    "McLeod",
    "McLoughlin",
    "McMackin",
    "McManus",
    "McMaster",
    "McMullan",
    "McMurphy",
    "McMurray",
    "McNab",
    "McNair",
    "McNamara",
    "McNaughton",
    "McNeill",
    "McNulty",
    "McPherson",
    "McQuillan",
    "McQuoid",
    "McRae",
    "McVitie",
    "Meadowes",
    "Meadows",
    "Melling",
    "Mellow",
    "Merrythought",
    "Mertin",
    "Metamorphus",
    "Middleton",
    "Mildew",
    "Mildmay",
    "Millar",
    "Millbank",
    "Milligan",
    "Mills",
    "Milner",
    "Milton",
    "Mintumble",
    "Miserden",
    "Misery",
    "Moffat",
    "Mojo",
    "Monaghan",
    "Moody",
    "Moon",
    "Mooney",
    "Moore",
    "Moran",
    "More",
    "Morgan",
    "Moriarty",
    "Morley",
    "Morlock",
    "Morrow",
    "Mortlake",
    "Mortlock",
    "Morton",
    "Mosby",
    "Moss",
    "Mostafa",
    "Mould",
    "Mouldywart",
    "Mudblood",
    "Muddle",
    "Muff",
    "Muffley",
    "Mulciber",
    "Mullet",
    "Mulready",
    "Mulvihill",
    "Mumbles",
    "Munslow",
    "Munson",
    "Munster",
    "Murdock",
    "Murphy",
    "Mush",
    "Mushy",
    "Musket",
    "Muskett",
    "Mystic",
    "Naggini",
    "Napier",
    "Napper",
    "Narkissos",
    "Nasty",
    "Naylor",
    "Needham",
    "Nellist",
    "Nellson",
    "Nelson",
    "Nelthorpe",
    "Nelwyn",
    "Nervosa",
    "Nettles",
    "Neville",
    "Newberry",
    "Newcomb",
    "Newman",
    "Newt",
    "Nickleby",
    "Niffler",
    "Nigger",
    "Nimrod",
    "Nipper",
    "Nitty",
    "Nixon",
    "Nobble",
    "Nodcock",
    "Noddle",
    "Noddy",
    "Noggin",
    "Nogood",
    "Noidea",
    "Nonsense",
    "Noodle",
    "Nooj",
    "Nook",
    "Nookingham",
    "Nopke",
    "Nork",
    "North",
    "Northbrook",
    "Northend",
    "Northfield",
    "Northman",
    "Norton",
    "Norwood",
    "Nott",
    "Nottley",
    "Novak",
    "Novelty",
    "Nudge",
    "Nugget",
    "Nuisance",
    "Nulbert",
    "Numbus",
    "Nunney",
    "Nutter",
    "Oakey",
    "Oakley",
    "Oblivion",
    "Oblong",
    "Obvious",
    "Ochre",
    "Ogle",
    "Ollerton",
    "Ollivander",
    "Ominous",
    "Onions",
    "Onslaught",
    "Opkirk",
    "Opworthy",
    "Oracle",
    "Orange",
    "Orchard",
    "Orlando",
    "Orton",
    "Orwell",
    "Ossory",
    "Othello",
    "Ott",
    "Otter",
    "Ottery",
    "Otton",
    "Ouldlodge",
    "Ouse",
    "Outhwaite",
    "Outlaw",
    "Outward",
    "Outwhistle",
    "Outwit",
    "Overland",
    "Owen",
    "Owens",
    "Oxford",
    "Oxfordshire",
    "Ozanne",
    "Paddock",
    "Parkinson",
    "Parseltongue",
    "Patil",
    "Peakes",
    "Peasegood",
    "Peebles",
    "Pepper",
    "Perkins",
    "Pettigrew",
    "Peverell",
    "Picquery",
    "Pike",
    "Pince",
    "Pippin",
    "Pirrip",
    "Pius",
    "Plunkett",
    "Podmore",
    "Pomfrey",
    "Ponsonby",
    "Potter",
    "Potts",
    "Poultney",
    "Prewett",
    "Price",
    "Pritchard",
    "Proudfoot",
    "Pruett",
    "Pucey",
    "Puddifoot",
    "Puffett",
    "Pulse",
    "Pye",
    "Quigley",
    "Quirke",
    "Quirrell",
    "Quist",
    "Quong",
    "Rabastan",
    "Radcliffe",
    "Ragnuk",
    "Rappaport",
    "Ravenclaw",
    "Rawle",
    "Reed",
    "Regulus",
    "Reiss",
    "Rellinger",
    "Rennervate",
    "Reynolds",
    "Rhodes",
    "Riddle",
    "Ripper",
    "Robards",
    "Robbins",
    "Roberts",
    "Robinson",
    "Rochfort",
    "Rockwood",
    "Rodriguez",
    "Rolanda",
    "Romilda",
    "Rookwood",
    "Roscoe",
    "Rose",
    "Rosier",
    "Rosmerta",
    "Runcorn",
    "Rusper",
    "Ruthven",
    "Ryan",
    "Ryddle",
    "Ryot",
    "Sabino",
    "Sacharissa",
    "Sagittarius",
    "Salazar",
    "Sallow",
    "Sampson",
    "Sanders",
    "Sanderson",
    "Sansa",
    "Santos",
    "Savage",
    "Saville",
    "Scabior",
    "Scamander",
    "Scarlett",
    "Scorpius",
    "Scrimgeour",
    "Scrimgour",
    "Seamus",
    "Seaton",
    "Selwyn",
    "Severus",
    "Shacklebolt",
    "Shafiq",
    "Shunpike",
    "Sidwell",
    "Sigrid",
    "Silva",
    "Silver",
    "Simms",
    "Sinistra",
    "Skeeter",
    "Skower",
    "Sloper",
    "Slughorn",
    "Slytherin",
    "Smallweed",
    "Smith",
    "Snape",
    "Sneeper",
    "Snyde",
    "Spangle",
    "Sparkle",
    "Sparkman",
    "Spencer",
    "Spinks",
    "Spinnet",
    "Spore",
    "Sprout",
    "Spryly",
    "Stamford",
    "Stanley",
    "Starling",
    "Stebbins",
    "Steele",
    "Stenner",
    "Stepney",
    "Stevens",
    "Stibbons",
    "Stimpson",
    "Stock",
    "Stoog",
    "Stooge",
    "Stooges",
    "Stoogis",
    "Stoogs",
    "Stoogy",
    "Strang",
    "Stratford",
    "Stroud",
    "Strykes",
    "Stump",
    "Sturgis",
    "Sulley",
    "Summers",
    "Sunninghill",
    "Surrey",
    "Sutcliffe",
    "Sutherland",
    "Sweet",
    "Swotter",
    "Sybill",
    "Talbot",
    "Tall",
    "Tamsin",
    "Tankworth",
    "Tarleton",
    "Tassell",
    "Tatting",
    "Tattle",
    "Tawny",
    "Teague",
    "Tempest",
    "Templeton",
    "Tentacula",
    "Terpsichore",
    "Terry",
    "Thicknesse",
    "Thistle",
    "Thomas",
    "Thomson",
    "Thorfinn",
    "Thornton",
    "Thrasher",
    "Threadneedle",
    "Thwaites",
    "Tibbles",
    "Tilcott",
    "Tillerman",
    "Timbers",
    "Timothy",
    "Tirza",
    "Titus",
    "Tofty",
    "Toke",
    "Tolipan",
    "Tonks",
    "Toothill",
    "Topsail",
    "Topsell",
    "Torpel",
    "Travers",
    "Trelawney",
    "Trickett",
    "Trinity",
    "Trionus",
    "Troy",
    "Truffle",
    "Truman",
    "Tuffnell",
    "Tugwood",
    "Tulipan",
    "Tulipan Sr.",
    "Tulipan Sr. Jr.",
    "Turner",
    "Turpin",
    "Twilfitt",
    "Twycross",
    "Umbridge",
    "Upton",
    "Urquhart",
    "Vaisey",
    "Valentine",
    "Vance",
    "Varley",
    "Vasey",
    "Veer",
    "Vekslar",
    "Vernon",
    "Vickers",
    "Vicky",
    "Victoria",
    "Vindictus",
    "Viridian",
    "Volant",
    "Voldemort",
    "Voles",
    "Vonderhaar",
    "Vosper",
    "Wagtail",
    "Walden",
    "Walker",
    "Wallace",
    "Walsingham",
    "Walton",
    "Wang",
    "Warbeck",
    "Ward",
    "Ware",
    "Warren",
    "Warrington",
    "Warwick",
    "Waterson",
    "Watkins",
    "Watson",
    "Weasley",
    "Weatherby",
    "Webber",
    "Webster",
    "Wedge",
    "Weedle",
    "Weedon",
    "Weezy",
    "Welch",
    "Weldon",
    "Wentworth",
    "Wepple",
    "West",
    "Westenberg",
    "Weston",
    "Whalen",
    "Wharton",
    "Wheeler",
    "Whelan",
    "Whipple",
    "Whisper",
    "White",
    "Whitfield",
    "Whitley",
    "Whitney",
    "Whitworth",
    "Whyte",
    "Wilberforce",
    "Wilbur",
    "Wilhelmina",
    "Wilkes",
    "Wilkins",
    "Wilkinson",
    "William",
    "Willis",
    "Willy",
    "Wilpert",
    "Wilson",
    "Wimple",
    "Wimpole",
    "Winchester",
    "Windle",
    "Winston",
    "Winter",
    "Wisteria",
    "Witchwood",
    "Witt",
    "Witterly",
    "Wolfe",
    "Wood",
    "Woodbine",
    "Woodbridge",
    "Woodcroft",
    "Woodruff",
    "Woodville",
    "Woollongong",
    "Wormtail",
    "Wormwood",
    "Worpel",
    "Wright",
    "Wurts",
    "Wycliff",
    "Xenophilius",
    "Yaxley",
    "Yewbeam",
    "York",
    "Yorke",
    "Young",
    "Yule",
    "Zabini",
    "Zacharias",
    "Zambini",
    "Zamojska",
    "Zamojski",
    "Zeller",
]


from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    generate_surname,
    generate_surname_less,
    styles
)
from . import arab, aztec, chinese, dwarven, elven, english, giant, halfling, japanese, mongolian, norsemen, orc, slavic, greek, steampunk, tolkien, viking, germanic, turkish, human, martin, jordan, erikson, roman, rowling, sapkowski


def generate_name(gender=choice(["female", "male"]), style=choice(styles), library=choice([True, False])):
    if type(gender) != str:
        raise TypeError("Invalid gender type.")
    if type(style) != str:
        raise TypeError("Invalid style type.")
    if type(library) != bool:
        raise TypeError("Invalid library type.")
    
    # Female names section
    if gender.lower() == "female":
        match style:
            case "elven":
                name = choice(elven.female_names) if library else generate_female_name(elven.female_prefix, elven.female_suffix)
            case "dwarven":
                name = choice(dwarven.female_names) if library else generate_female_name(dwarven.female_prefix, dwarven.female_suffix, min=1, max=2)
            case "giant":
                name = choice(giant.female_names) if library else generate_female_name(giant.female_prefix, giant.female_suffix, min=0, max=1)
            case "halfling":
                name = choice(halfling.female_names) if library else generate_female_name(halfling.female_prefix, halfling.female_suffix)
            case "orc":
                name = choice(orc.female_names) if library else generate_female_name(orc.female_prefix, orc.female_suffix, min=0, max=1)
            case "steampunk":
                name = choice(steampunk.female_names_lbr) if library else choice(steampunk.female_names)
            case "human":
                name = choice(human.female_names)
            case "english":
                name = choice(english.female_names_lbr) if library else choice(english.female_names)
            case "greek":
                name = choice(greek.female_names) if library else generate_female_name(greek.female_prefix, greek.female_suffix)
            case "norsemen":
                name = choice(norsemen.female_names) if library else generate_female_name(norsemen.female_prefix, norsemen.female_suffix, min=0, max=1)
            case "arab":
                name = choice(arab.female_names) if library else generate_female_name(arab.female_prefix, arab.female_suffix, min=1, max=2)
            case "japanese":
                name = choice(japanese.female_names) if library else generate_female_name(japanese.female_prefix, japanese.female_suffix)
            case "viking":
                name = choice(viking.female_names) if library else generate_female_name(viking.female_prefix, viking.female_suffix)
            case "germanic":
                name = choice(germanic.female_names) if library else generate_female_name(germanic.female_prefix, germanic.female_suffix)
            case "turkish":
                name = choice(turkish.female_names) if library else generate_female_name(turkish.female_prefix, turkish.female_suffix)
            case "chinese":
                name = choice(chinese.female_names) if library else generate_female_name(chinese.female_prefix, chinese.female_suffix)
            case "mongolian":
                name = choice(mongolian.female_names) if library else generate_female_name(mongolian.female_prefix, mongolian.female_suffix)
            case "slavic":
                name = choice(slavic.female_names) if library else generate_female_name(slavic.female_prefix, slavic.female_suffix)
            case "aztec":
                name = choice(aztec.female_names) if library else generate_female_name(aztec.female_prefix, aztec.female_suffix)
            case "roman":
                name = choice(roman.female_names) if library else generate_female_name(roman.female_prefix, roman.female_suffix)
            case "tolkien":
                name = choice(tolkien.female_names) if library else generate_female_name(tolkien.female_prefix, tolkien.female_suffix, min=1, max=2)
            case "martin":
                name = choice(martin.female_names) if library else generate_female_name(martin.female_prefix, martin.female_suffix, min=0, max=1)
            case "jordan":
                name = choice(jordan.female_names) if library else generate_female_name(jordan.female_prefix, jordan.female_suffix, min=0, max=2)
            case "erikson":
                name = choice(erikson.female_names) if library else generate_female_name(erikson.female_prefix, jordan.female_suffix, min=0, max=2)
            case "rowling":
                name = choice(rowling.female_names) if library else generate_female_name(rowling.female_prefix, rowling.female_suffix)
            case "sapkowski":
                name = choice(sapkowski.female_names) if library else generate_female_name(sapkowski.female_prefix, sapkowski.female_suffix)

    # Male names section
    elif gender.lower() == "male":
        match style:
            case "elven":
                name = choice(elven.male_names) if library else generate_male_name(elven.male_prefix, elven.male_suffix)
            case "dwarven":
                name = choice(dwarven.male_names) if library else generate_male_name(dwarven.male_prefix, dwarven.male_suffix)
            case "giant":
                name = choice(giant.male_names) if library else generate_male_name(giant.male_prefix, giant.male_suffix, min=0, max=1)
            case "halfling":
                name = choice(halfling.male_names) if library else generate_male_name(halfling.male_prefix, halfling.male_suffix)
            case "orc":
                name = choice(orc.male_names) if library else generate_male_name(orc.male_prefix, orc.male_suffix, min=0, max=1)
            case "steampunk":
                name = choice(steampunk.male_names_lbr) if library else choice(steampunk.male_names)
            case "human":
                name = choice(human.male_names)
            case "english":
                name = choice(english.male_names_lbr) if library else choice(english.male_names)
            case "greek":
                name = choice(greek.male_names) if library else generate_male_name(greek.male_prefix, greek.male_suffix)
            case "norsemen":
                name = choice(norsemen.male_names) if library else generate_male_name(norsemen.male_prefix, norsemen.male_suffix, min=0, max=1)
            case "arab":
                name = choice(arab.male_names) if library else generate_male_name(arab.male_prefix, arab.male_suffix, min=1, max=2)
            case "japanese":
                name = choice(japanese.male_names) if library else generate_male_name(japanese.male_prefix, japanese.male_suffix)
            case "viking":
                name = choice(viking.male_names) if library else generate_male_name(viking.male_prefix, viking.male_suffix)
            case "germanic":
                name = choice(germanic.male_names) if library else generate_male_name(germanic.male_prefix, germanic.male_suffix)
            case "turkish":
                name = choice(turkish.male_names) if library else generate_male_name(turkish.male_prefix, turkish.male_suffix)
            case "chinese":
                name = choice(chinese.male_names) if library else generate_male_name(chinese.male_prefix, chinese.male_suffix)
            case "mongolian":
                name = choice(mongolian.male_names) if library else generate_male_name(mongolian.male_prefix, mongolian.male_suffix)
            case "slavic":
                name = choice(slavic.male_names) if library else generate_male_name(slavic.male_prefix, slavic.male_suffix)
            case "aztec":
                name = choice(aztec.male_names) if library else generate_male_name(aztec.male_prefix, aztec.male_suffix)
            case "roman":
                name = choice(roman.male_names) if library else generate_male_name(roman.male_prefix, roman.male_suffix)
            case "tolkien":
                name = choice(tolkien.male_names) if library else generate_male_name(tolkien.male_prefix, tolkien.male_suffix, min=1, max=2)
            case "martin":
                name = choice(martin.male_names) if library else generate_male_name(martin.male_prefix, martin.male_suffix, min=0, max=1)
            case "jordan":
                name = choice(jordan.male_names) if library else generate_male_name(jordan.male_prefix, jordan.male_suffix, min=0, max=2)
            case "erikson":
                name = choice(erikson.male_names) if library else generate_male_name(erikson.male_prefix, erikson.male_suffix, min=0, max=2)
            case "rowling":
                name = choice(rowling.male_names) if library else generate_male_name(rowling.male_prefix, rowling.male_suffix)
            case "sapkowski":
                name = choice(sapkowski.male_names) if library else generate_male_name(sapkowski.male_prefix, sapkowski.male_suffix)
    else:
        raise ValueError("Invalid gender specified. Please choose 'male' or 'female'.")

    # Surnames section
    if style.lower() == "elven":
        surname = choice(elven.surnames) if library else generate_surname(elven.surname_syllables)
    elif style.lower() == "dwarven":
        surname = choice(dwarven.surnames) if library else generate_surname(dwarven.surname_syllables, min=1, max=3)
    elif style.lower() == "giant":
        surname = choice(giant.surnames) if library else generate_surname_less(giant.surname_prefix, giant.surname_suffix)
    elif style.lower() == "halfling":
        surname = choice(halfling.surnames) if library else generate_surname_less(halfling.surname_prefix, halfling.surname_suffix)
    elif style.lower() == "orc":
        surname = choice(orc.surnames) if library else choice(orc.titles)
    elif style.lower() == "steampunk":
        surname = choice(steampunk.surnames_lbr) if library else choice(steampunk.surnames)
    elif style.lower() == "human":
        surname = choice(human.surnames) if library else generate_surname_less(human.surname_prefix, human.surname_suffix)
    elif style.lower() == "english":
        surname = choice(english.surnames_lbr) if library else choice(english.surnames)
    elif style.lower() == "greek":
        surname = choice(greek.surnames) if library else generate_surname_less(greek.surname_prefix, greek.surname_suffix)
    elif style.lower() == "norsemen":
        surname = choice(norsemen.surnames) if library else generate_surname_less(norsemen.surname_prefix, norsemen.surname_suffix)
    elif style.lower() == "arab":
        surname = choice(arab.surnames) if library else generate_surname_less(arab.surname_prefix, arab.surname_suffix)
    elif style.lower() == "japanese":
        surname = choice(japanese.surnames) if library else generate_surname_less(japanese.surname_prefix, japanese.surname_suffix)
    elif style.lower() == "viking":
        surname = (choice(viking.female_surnames) if gender == "female" else choice(viking.male_surnames)) if library else generate_surname_less(viking.surname_prefix, viking.surname_suffix)
    elif style.lower() == "germanic":
        surname = choice(germanic.surnames) if library else generate_surname_less(germanic.surname_prefix, germanic.surname_suffix)
    elif style.lower() == "turkish":
        surname = choice(turkish.surnames) if library else generate_surname_less(turkish.surname_prefix, turkish.surname_suffix)
    elif style.lower() == "chinese":
        surname = choice(chinese.surnames) if library else generate_surname_less(chinese.surname_prefix, chinese.surname_suffix)
    elif style.lower() == "mongolian":
        surname = choice(mongolian.surnames) if library else generate_surname_less(mongolian.surname_prefix, mongolian.surname_suffix)
    elif style.lower() == "slavic":
        surname = choice(slavic.surnames) if library else generate_surname_less(slavic.surname_prefix, slavic.surname_suffix)
    elif style.lower() == "aztec":
        surname = choice(aztec.surnames) if library else generate_surname_less(aztec.surname_prefix, aztec.surname_suffix)
    elif style.lower() == "roman":
        surname = choice(roman.surnames) if library else generate_surname_less(roman.surname_prefix, roman.surname_suffix)
    elif style.lower() == "tolkien":
        surname = choice(tolkien.surnames) if library else generate_surname_less(tolkien.surname_prefix, tolkien.surname_suffix)
    elif style.lower() == "martin":
        surname = choice(martin.surnames) if library else generate_surname_less(martin.surname_prefix, martin.surname_suffix)
    elif style.lower() == "jordan":
        surname = choice(jordan.surnames) if library else generate_surname_less(jordan.surname_prefix, jordan.surname_suffix)
    elif style.lower() == "erikson":
        surname = choice(erikson.surnames) if library else generate_surname(erikson.surname_syllables)
    elif style.lower() == "rowling":
        surname = choice(rowling.surnames)
    elif style.lower() == "sapkowski":
        surname = choice(sapkowski.surnames) if library else generate_surname_less(sapkowski.surname_prefix, sapkowski.surname_suffix)
    else:
        raise ValueError(
            "Invalid style specified. Please choose a valid style between 'elven', 'dwarven', 'giant', 'halfling', 'orc', 'steampunk', 'human', 'english', 'greek', 'norsemen', 'arab', 'japanese', 'viking', 'germanic', 'turkish', 'chinese', 'mongolian', 'slavic', 'aztec', 'roman', 'tolkien', 'martin', 'jordan', 'erikson', 'rowling', or 'sapkowski'."
        )

    return f"{name} {surname}"


if __name__ == "__main__":
    generated_name = generate_name()
    print(generated_name)



female_prefix = [
    "ard",
    "bert",
    "bold",
    "brand",
    "dolf",
    "fred",
    "frid",
    "gard",
    "hardt",
    "helm",
    "her",
    "mar",
    "olf",
    "ric",
    "rich",
    "rik",
    "wald",
    "ward",
    "win",
]

female_suffix = [
    "a",
    "burg",
    "dís",
    "fred",
    "gard",
    "gund",
    "hild",
    "hildis",
    "lind",
    "run",
    "sind",
    "svein",
    "thild",
    "trud",
    "unn",
    "vild",
    "vind",
    "wig",
]

male_prefix = [
    "ald",
    "alf",
    "am",
    "arn",
    "ber",
    "brand",
    "dank",
    "ed",
    "ein",
    "ern",
    "frid",
    "ger",
    "gott",
    "grim",
    "gun",
    "hart",
    "hein",
    "helm",
    "her",
    "hild",
    "hugo",
    "karl",
    "leif",
    "loth",
    "nor",
    "os",
    "osw",
    "rad",
    "rich",
    "roth",
    "sig",
    "thor",
    "ulf",
    "wal",
    "win",
    "wolf",
]

male_suffix = [
    "ard",
    "bert",
    "bold",
    "brand",
    "dolf",
    "fred",
    "frid",
    "gard",
    "hardt",
    "helm",
    "her",
    "mar",
    "olf",
    "ric",
    "rich",
    "rik",
    "wald",
    "ward",
    "win",
]

surname_prefix = [
    "ber",
    "dorn",
    "eis",
    "frey",
    "gau",
    "hart",
    "johann",
    "kraus",
    "lud",
    "meier",
    "nacht",
    "ott",
    "pfeffer",
    "rhein",
    "schwarz",
    "stein",
    "thor",
    "ulrich",
    "vogel",
    "wagner",
    "zeis",
]

surname_suffix = [
    "bach",
    "berg",
    "brand",
    "feld",
    "fels",
    "fisch",
    "grimm",
    "hammer",
    "hoff",
    "kamp",
    "müller",
    "schmidt",
    "schneider",
    "stern",
    "wald",
    "weber",
    "wolf",
    "wulf",
    "zimmer",
]

female_names = [
    "Adalheid",
    "Agatha",
    "Alberada",
    "Aldegund",
    "Aldgund",
    "Alfriede",
    "Alheidis",
    "Alruna",
    "Amalberga",
    "Amalia",
    "Ansgard",
    "Ansgunde",
    "Astrid",
    "Berta",
    "Bertha",
    "Brigitta",
    "Brunhild",
    "Dagmar",
    "Eberhild",
    "Edda",
    "Edelgard",
    "Edeltraud",
    "Edith",
    "Eduarda",
    "Eilika",
    "Elisabeth",
    "Else",
    "Emmaline",
    "Engelberga",
    "Ermentrud",
    "Erna",
    "Ethelinde",
    "Friedegund",
    "Friederike",
    "Friedhild",
    "Friedlinde",
    "Gabriele",
    "Gebharda",
    "Gerburg",
    "Gerda",
    "Gerhild",
    "Gerlind",
    "Gertrud",
    "Gisela",
    "Gislinde",
    "Godelind",
    "Gotelind",
    "Grimhild",
    "Gudrun",
    "Hedwig",
    "Heidrun",
    "Heilwig",
    "Helena",
    "Helgard",
    "Hella",
    "Henrike",
    "Hilde",
    "Hildegard",
    "Hiltrud",
    "Ilse",
    "Imma",
    "Immelind",
    "Inge",
    "Ingeborg",
    "Ingrid",
    "Irmgard",
    "Irmingard",
    "Isolde",
    "Johanna",
    "Karin",
    "Karoline",
    "Katharina",
    "Klara",
    "Klothilde",
    "Kriemhild",
    "Liesel",
    "Lieselotte",
    "Linda",
    "Liselotte",
    "Lothild",
    "Luise",
    "Magdalena",
    "Margarita",
    "Margot",
    "Marlene",
    "Matilda",
    "Mechthild",
    "Melisande",
    "Mona",
    "Oda",
    "Olga",
    "Ortrud",
    "Regina",
    "Ricarda",
    "Rita",
    "Rosalinde",
    "Roswitha",
    "Sabine",
    "Sibylle",
    "Siegrid",
    "Siglinde",
    "Sigrid",
    "Silke",
    "Solveig",
    "Sophie",
    "Swanhild",
    "Sylvia",
    "Theodora",
    "Theresia",
    "Ursula",
    "Walburga",
    "Waldtraud",
    "Wanda",
    "Wilfrieda",
    "Wilhelmina",
    "Winifred",
    "Yvonne",
    "Zelda",
]

male_names = [
    "Adalard",
    "Adalbert",
    "Adalhard",
    "Adalhelm",
    "Adalmar",
    "Adalric",
    "Adalwin",
    "Adalwolf",
    "Adelbert",
    "Adelhard",
    "Adelmar",
    "Adelulf",
    "Ademar",
    "Adolar",
    "Adolph",
    "Aldo",
    "Aldric",
    "Alfred",
    "Alwin",
    "Amalric",
    "Amelung",
    "Anselm",
    "Armin",
    "Arnulf",
    "Baldemar",
    "Balderich",
    "Baldo",
    "Baldric",
    "Balthasar",
    "Berenger",
    "Bernard",
    "Bernulf",
    "Berthold",
    "Bertram",
    "Bruno",
    "Conrad",
    "Dagobert",
    "Dietrich",
    "Eberhard",
    "Edwin",
    "Eginhard",
    "Eldric",
    "Emmerich",
    "Erhard",
    "Ermenrich",
    "Erwin",
    "Ferdinand",
    "Folker",
    "Folkmar",
    "Franz",
    "Frederick",
    "Friedrich",
    "Gebhard",
    "Gerard",
    "Gero",
    "Gerwin",
    "Giselbert",
    "Gisulf",
    "Gottfried",
    "Gunther",
    "Hagen",
    "Hanno",
    "Hartmann",
    "Heinrich",
    "Helmut",
    "Herbert",
    "Heribert",
    "Hermann",
    "Hildebrand",
    "Hubert",
    "Hugo",
    "Ingmar",
    "Ivo",
    "Karl",
    "Kaspar",
    "Konrad",
    "Lambert",
    "Lando",
    "Leopold",
    "Lothar",
    "Ludwig",
    "Magnus",
    "Markus",
    "Matthias",
    "Maximilian",
    "Norbert",
    "Odilo",
    "Odo",
    "Otto",
    "Pepin",
    "Rainer",
    "Reinhard",
    "Rolf",
    "Rudolf",
    "Siegfried",
    "Sigbert",
    "Sigmund",
    "Theobald",
    "Theodoric",
    "Ulrich",
    "Valentin",
    "Volkmar",
    "Waldo",
    "Walther",
    "Werner",
    "Wido",
    "Wilhelm",
    "Willibald",
    "Winfred",
    "Wolfgang",
    "Wulfric",
    "Zigmund",
]

surnames = [
    "Adler",
    "Albrecht",
    "Baumann",
    "Beck",
    "Becker",
    "Berger",
    "Bergmann",
    "Beyer",
    "Bischof",
    "Blau",
    "Brauer",
    "Braun",
    "Brinkmann",
    "Brückner",
    "Buchholz",
    "Busch",
    "Christ",
    "Dietrich",
    "Döring",
    "Eckert",
    "Ehrlich",
    "Eichler",
    "Enders",
    "Engel",
    "Ernst",
    "Fischer",
    "Franke",
    "Freitag",
    "Fröhlich",
    "Fröhner",
    "Geiger",
    "Gerlach",
    "Graf",
    "Gruber",
    "Günther",
    "Hahn",
    "Hartmann",
    "Hartwig",
    "Hauser",
    "Heinrich",
    "Heller",
    "Hermann",
    "Herrmann",
    "Heß",
    "Hirsch",
    "Hoffmann",
    "Hofmann",
    "Holz",
    "Huber",
    "Jung",
    "Kaiser",
    "Keller",
    "Kemper",
    "Kessler",
    "Kirsch",
    "Klein",
    "Koch",
    "Konrad",
    "Kramer",
    "Kraus",
    "Krause",
    "Krüger",
    "Köhler",
    "König",
    "Kühn",
    "Lang",
    "Lehmann",
    "Lenz",
    "Lindemann",
    "Lorenz",
    "Ludwig",
    "Maier",
    "Martin",
    "Maurer",
    "Mayer",
    "Meier",
    "Meyer",
    "Miller",
    "Morgenstern",
    "Moser",
    "Möller",
    "Müller",
    "Neumann",
    "Ott",
    "Peters",
    "Pfeiffer",
    "Pohl",
    "Rau",
    "Reich",
    "Reinhardt",
    "Renner",
    "Richter",
    "Ritter",
    "Roth",
    "Rudolph",
    "Sauer",
    "Schilling",
    "Schlüter",
    "Schmid",
    "Schmidt",
    "Schneider",
    "Scholz",
    "Schreiber",
    "Schreiner",
    "Schroeder",
    "Schubert",
    "Schulz",
    "Schumacher",
    "Schuster",
    "Schwarz",
    "Schäfer",
    "Seidel",
    "Seifert",
    "Simon",
    "Sommer",
    "Stark",
    "Steffens",
    "Stein",
    "Steiner",
    "Sturm",
    "Theis",
    "Thiel",
    "Thomas",
    "Vogel",
    "Vogt",
    "Voigt",
    "Wagner",
    "Walter",
    "Weber",
    "Weiss",
    "Weiß",
    "Werner",
    "Wiedemann",
    "Wiegand",
    "Wimmer",
    "Winter",
    "Wirth",
    "Wittmann",
    "Wolf",
    "Wolff",
    "Wunderlich",
    "Ziegler",
    "Zimmermann",
]




female_names = [
    "Adelaide",
    "Adriana",
    "Amara",
    "Amaryllis",
    "Anastasia",
    "Arabella",
    "Ariadne",
    "Arianwen",
    "Astoria",
    "Aurelia",
    "Brielle",
    "Calliope",
    "Cassandra",
    "Celestia",
    "Cressida",
    "Dahlia",
    "Elara",
    "Eleanor",
    "Elowen",
    "Elysia",
    "Emmeline",
    "Evaine",
    "Evangeline",
    "Evelina",
    "Fiona",
    "Fiora",
    "Genevieve",
    "Ginevra",
    "Giselle",
    "Guinevere",
    "Gwendolyn",
    "Helena",
    "Helene",
    "Iliana",
    "Imelda",
    "Isabeau",
    "Isolde",
    "Jessamine",
    "Jocelyn",
    "Lavinia",
    "Lorelei",
    "Lyra",
    "Maelisande",
    "Marigold",
    "Melisande",
    "Mirella",
    "Morgana",
    "Morwenna",
    "Nerissa",
    "Octavia",
    "Ophelia",
    "Oriana",
    "Pandora",
    "Persephone",
    "Quintessa",
    "Ravenna",
    "Rosalind",
    "Rosamund",
    "Rowena",
    "Sabrina",
    "Selene",
    "Seraphina",
    "Seraphine",
    "Sylvana",
    "Tatiana",
    "Thalia",
    "Titania",
    "Ursula",
    "Vespera",
    "Viola",
    "Vivienne",
    "Wilhelmina",
    "Winifred",
    "Xanthe",
    "Yara",
    "Yvette",
    "Zephyrine",
]

male_names = [
    "Ambrose",
    "Arthur",
    "Balthazar",
    "Benedict",
    "Caius",
    "Cassius",
    "Cedric",
    "Dominic",
    "Dorian",
    "Edmund",
    "Edric",
    "Emeric",
    "Ezekiel",
    "Felix",
    "Finnian",
    "Frederick",
    "Galahad",
    "Gareth",
    "Gawain",
    "Gerard",
    "Gideon",
    "Hadrian",
    "Harold",
    "Hector",
    "Horatio",
    "Ignatius",
    "Jareth",
    "Jasper",
    "Jeremiah",
    "Kieran",
    "Lancelot",
    "Lazarus",
    "Leander",
    "Leopold",
    "Luther",
    "Lysander",
    "Magnus",
    "Maximilian",
    "Merrick",
    "Nathaniel",
    "Oberon",
    "Orlando",
    "Oswald",
    "Percival",
    "Peregrine",
    "Quentin",
    "Quirinus",
    "Raphael",
    "Reginald",
    "Roderick",
    "Sebastian",
    "Solomon",
    "Sylvester",
    "Thaddeus",
    "Theobald",
    "Theron",
    "Tristan",
    "Tristram",
    "Ulric",
    "Ulysses",
    "Uriah",
    "Valerian",
    "Vance",
    "Victor",
    "Wilfred",
    "Winston",
    "Xander",
    "Xavier",
    "Yale",
    "Yorick",
    "Zacharias",
    "Zephyr",
]

surname_prefix = [
    "Amber",
    "Black",
    "Blade",
    "Blaze",
    "Blood",
    "Bright",
    "Dark",
    "Dawn",
    "Dragon",
    "Dusk",
    "Fire",
    "Frost",
    "Golden",
    "Hawk",
    "Iron",
    "Mist",
    "Moon",
    "Night",
    "Oak",
    "Raven",
    "Shadow",
    "Silver",
    "Star",
    "Steel",
    "Stone",
    "Storm",
    "Swift",
    "Sword",
    "Thorn",
    "Thunder",
    "Valiant",
    "White",
    "Wind",
    "Winter",
    "Wolf",
]

surname_suffix = [
    "arrow",
    "bane",
    "bark",
    "beard",
    "blade",
    "blood",
    "breaker",
    "brook",
    "caster",
    "claw",
    "dusk",
    "eye",
    "fall",
    "fang",
    "field",
    "fire",
    "fist",
    "flame",
    "foot",
    "hawk",
    "heart",
    "helm",
    "leaf",
    "mantle",
    "mist",
    "moon",
    "raven",
    "rider",
    "scale",
    "shadow",
    "shard",
    "shield",
    "song",
    "spear",
    "steel",
    "stone",
    "storm",
    "strike",
    "sword",
    "thistle",
    "thorn",
    "thunder",
    "vale",
    "walker",
    "warden",
    "watch",
    "weaver",
    "wind",
    "wing",
    "wood",
]

surnames = [
    "Acker",
    "Adler",
    "Albrecht",
    "Angermann",
    "Arnold",
    "Auerbach",
    "Bauer",
    "Baumann",
    "Baumgartner",
    "Becker",
    "Berger",
    "Bergmann",
    "Beyer",
    "Beyerlein",
    "Biedermann",
    "Blume",
    "Bock",
    "Borchardt",
    "Brandt",
    "Braun",
    "Brinkmann",
    "Brunner",
    "Bucher",
    "Conrad",
    "Dietrich",
    "Dorn",
    "Drescher",
    "Eberhardt",
    "Ebert",
    "Eckert",
    "Eggert",
    "Eisenmann",
    "Engel",
    "Fink",
    "Fischer",
    "Fleischer",
    "Fleischmann",
    "Franke",
    "Freitag",
    "Frey",
    "Friedrich",
    "Fuchs",
    "Gebhardt",
    "Geier",
    "Gerber",
    "Gottschalk",
    "Graf",
    "Groß",
    "Gruber",
    "Gräf",
    "Gärtner",
    "Haas",
    "Hagen",
    "Hahn",
    "Hammer",
    "Hartmann",
    "Hartwig",
    "Haupt",
    "Hecht",
    "Heimann",
    "Hein",
    "Heinrich",
    "Held",
    "Heller",
    "Hermann",
    "Herzog",
    "Hirsch",
    "Hoffmann",
    "Holländer",
    "Holzer",
    "Holzknecht",
    "Hoppe",
    "Huber",
    "Hubert",
    "Höfer",
    "Jacob",
    "Jansen",
    "Jung",
    "Jäger",
    "Jänicke",
    "Kaiser",
    "Kappler",
    "Kaufmann",
    "Keller",
    "Kiefer",
    "Kirsch",
    "Klein",
    "Knecht",
    "Koch",
    "Kopp",
    "Krause",
    "Krauß",
    "Krebs",
    "Kretschmann",
    "Krug",
    "Krüger",
    "Kuhn",
    "Kunz",
    "Kurz",
    "Köhler",
    "König",
    "Kühn",
    "Landgraf",
    "Lang",
    "Lange",
    "Langenberg",
    "Lechner",
    "Lehmann",
    "Leibnitz",
    "Lindemann",
    "Lorenz",
    "Ludwig",
    "Maier",
    "Mann",
    "Martin",
    "Maurer",
    "Mayer",
    "Meier",
    "Meister",
    "Merz",
    "Messer",
    "Meyer",
    "März",
    "Müller",
    "Neubauer",
    "Neumann",
    "Nussbaum",
    "Pfeiffer",
    "Pohl",
    "Popp",
    "Rapp",
    "Reinhardt",
    "Reiter",
    "Richter",
    "Riedel",
    "Ritter",
    "Rohde",
    "Roth",
    "Rothmann",
    "Sachs",
    "Sauer",
    "Schaller",
    "Schell",
    "Schick",
    "Schindler",
    "Schmid",
    "Schmidt",
    "Schmitz",
    "Schneider",
    "Scholz",
    "Schott",
    "Schreiber",
    "Schreiner",
    "Schubert",
    "Schulz",
    "Schumacher",
    "Schuster",
    "Schwab",
    "Schwarz",
    "Schweitzer",
    "Schäfer",
    "Seidel",
    "Seligmann",
    "Simon",
    "Sommer",
    "Sonnemann",
    "Sperling",
    "Stein",
    "Steiner",
    "Stern",
    "Stolz",
    "Sturm",
    "Taubert",
    "Thiel",
    "Thiele",
    "Thomas",
    "Ullmann",
    "Ulrich",
    "Unger",
    "Vogel",
    "Vogt",
    "Voigt",
    "Wagner",
    "Walter",
    "Walther",
    "Weber",
    "Weiß",
    "Wendt",
    "Werner",
    "Wieland",
    "Winkler",
    "Winter",
    "Wolf",
    "Wolff",
    "Zahn",
    "Zander",
    "Ziegler",
    "Zimmermann",
    "Zink",
    "Zoller",
    "Zorn",
    "Zuber",
    "Zumwinkel",
]



female_prefix = [
    "ai",
    "an",
    "bai",
    "bing",
    "cui",
    "dan",
    "fang",
    "fen",
    "guan",
    "hong",
    "hua",
    "jing",
    "lan",
    "li",
    "lu",
    "mei",
    "ming",
    "na",
    "ning",
    "ping",
    "qi",
    "qian",
    "rong",
    "shuang",
    "ting",
    "wan",
    "xi",
    "xia",
    "xiang",
    "yan",
    "ying",
    "yun",
    "zhen",
    "zhu",
]

female_suffix = [
    "hua",
    "ying",
    "yun",
    "lan",
    "mei",
    "xiu",
    "jiao",
    "li",
    "fang",
    "ping",
    "rong",
    "xue",
    "hua",
    "zhen",
    "ying",
    "xiang",
    "ting",
    "na",
    "ning",
    "yun",
    "fang",
    "yan",
    "ying",
    "jing",
    "hua",
    "ying",
    "xin",
    "lian",
    "xi",
    "xia",
    "yu",
    "jing",
    "hua",
]

male_prefix = [
    "bei",
    "bo",
    "cai",
    "chen",
    "chi",
    "chong",
    "da",
    "ding",
    "dong",
    "feng",
    "fu",
    "gong",
    "gu",
    "han",
    "hong",
    "hu",
    "ji",
    "jian",
    "jin",
    "ju",
    "jun",
    "kai",
    "li",
    "lin",
    "ming",
    "nan",
    "ning",
    "peng",
    "qing",
    "quan",
    "ren",
    "rong",
    "sheng",
    "shi",
    "shu",
    "tao",
    "tian",
    "wei",
    "wen",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xin",
    "xing",
    "xiong",
    "yang",
    "yi",
    "yong",
    "yu",
    "yuan",
    "yue",
    "yun",
    "zhan",
    "zhen",
    "zheng",
    "zhong",
    "zhou",
    "zhu",
    "zhuo",
]

male_suffix = [
    "bin",
    "bo",
    "cheng",
    "chun",
    "cong",
    "da",
    "dan",
    "deng",
    "dong",
    "feng",
    "gang",
    "guo",
    "hao",
    "he",
    "heng",
    "hong",
    "hua",
    "huang",
    "jian",
    "jing",
    "jun",
    "kai",
    "li",
    "liang",
    "lin",
    "ming",
    "nan",
    "ning",
    "peng",
    "qiang",
    "qing",
    "quan",
    "ren",
    "rong",
    "sheng",
    "shi",
    "shuai",
    "song",
    "tao",
    "ting",
    "wei",
    "wen",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xin",
    "xing",
    "xiong",
    "yang",
    "yi",
    "yong",
    "yu",
    "yuan",
    "yue",
    "yun",
    "zhan",
    "zhen",
    "zheng",
    "zhong",
    "zhou",
    "zhu",
    "zhuo",
]

surname_prefix = [
    "bai",
    "cao",
    "chen",
    "dai",
    "ding",
    "du",
    "fan",
    "fu",
    "gan",
    "gu",
    "guo",
    "han",
    "hu",
    "hua",
    "huang",
    "ji",
    "jiang",
    "jin",
    "kong",
    "li",
    "lian",
    "lin",
    "liu",
    "lu",
    "lv",
    "ma",
    "meng",
    "nan",
    "ni",
    "pan",
    "peng",
    "qi",
    "qian",
    "qin",
    "qiu",
    "shao",
    "shen",
    "shi",
    "song",
    "su",
    "sun",
    "tan",
    "tang",
    "wan",
    "wang",
    "wei",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xiao",
    "xie",
    "xiong",
    "xu",
    "yang",
    "yi",
    "yin",
    "yuan",
    "zeng",
    "zhang",
    "zhao",
    "zhen",
    "zheng",
    "zhou",
    "zhu",
    "zhao",
]

surname_suffix = [
    "an",
    "ang",
    "ao",
    "bei",
    "bin",
    "bo",
    "chan",
    "chang",
    "cheng",
    "chong",
    "chu",
    "chuan",
    "chun",
    "cui",
    "dan",
    "dang",
    "deng",
    "dong",
    "fan",
    "fang",
    "fen",
    "feng",
    "fu",
    "gan",
    "gang",
    "gu",
    "guan",
    "gui",
    "hao",
    "he",
    "heng",
    "hong",
    "hou",
    "hu",
    "huang",
    "hui",
    "ji",
    "jian",
    "jiang",
    "jiao",
    "jin",
    "jing",
    "kang",
    "ke",
    "kong",
    "kuai",
    "kun",
    "lan",
    "li",
    "lian",
    "liang",
    "lin",
    "ling",
    "long",
    "lu",
    "luan",
    "lun",
    "mei",
    "min",
    "ming",
    "mou",
    "nan",
    "ning",
    "nong",
    "nuan",
    "peng",
    "qi",
    "qian",
    "qiang",
    "qin",
    "qing",
    "qiong",
    "quan",
    "rui",
    "run",
    "shan",
    "sheng",
    "shi",
    "shou",
    "song",
    "su",
    "sun",
    "tai",
    "tang",
    "ting",
    "tong",
    "wei",
    "wen",
    "wu",
    "xi",
    "xia",
    "xiang",
    "xiao",
    "xin",
    "xing",
    "xiong",
    "xu",
    "yang",
    "yan",
    "yang",
    "yin",
    "ying",
    "yu",
    "yuan",
    "yun",
    "zhan",
    "zhang",
    "zhao",
    "zhen",
    "zheng",
    "zhi",
    "zhong",
    "zhou",
    "zhu",
    "zong",
]

female_names = [
    "Ai",
    "An",
    "Ao",
    "Bai",
    "Bi",
    "Bing",
    "Bo",
    "Cai",
    "Cen",
    "Ci",
    "Dai",
    "Dan",
    "Ding",
    "Dong",
    "E",
    "Fang",
    "Fangfang",
    "Fei",
    "Fen",
    "Fu",
    "Gao",
    "Gui",
    "Han",
    "Hong",
    "Hongli",
    "Hongmei",
    "Hongyun",
    "Hu",
    "Hua",
    "Hui",
    "Huifang",
    "Huihui",
    "Huiling",
    "Ji",
    "Jia",
    "Jiajia",
    "Jian",
    "Jiang",
    "Jiao",
    "Jie",
    "Jin",
    "Jing",
    "Jingjing",
    "Jingyun",
    "Ju",
    "Juan",
    "Jun",
    "Kai",
    "Lan",
    "Li",
    "Lian",
    "Liang",
    "Lihua",
    "Lili",
    "Lin",
    "Lina",
    "Ling",
    "Lingling",
    "Liu",
    "Liuying",
    "Liya",
    "Lu",
    "Luan",
    "Lü",
    "Man",
    "Mei",
    "Meihua",
    "Meimei",
    "Min",
    "Ming",
    "Minmin",
    "Mu",
    "Nan",
    "Ning",
    "Nu",
    "Pang",
    "Ping",
    "Pingping",
    "Qi",
    "Qian",
    "Qiang",
    "Qianqian",
    "Qiaoling",
    "Qin",
    "Qing",
    "Qingqing",
    "Qingyuan",
    "Qiong",
    "Qiqi",
    "Qiu",
    "Ran",
    "Rong",
    "Rongrong",
    "Ru",
    "Ruo",
    "Shan",
    "Shang",
    "Shanshan",
    "Shao",
    "Shi",
    "Shu",
    "Shuang",
    "Si",
    "Su",
    "Tang",
    "Tiantian",
    "Ting",
    "Tingting",
    "Wan",
    "Wei",
    "Weili",
    "Wen",
    "Wenjuan",
    "Wenqian",
    "Wenwen",
    "Wu",
    "Xi",
    "Xia",
    "Xiang",
    "Xiao",
    "Xiaofeng",
    "Xiaohong",
    "Xiaohua",
    "Xiaojuan",
    "Xiaoling",
    "Xiaomei",
    "Xiaoqin",
    "Xiaowei",
    "Xiaoxia",
    "Xiaoxiao",
    "Xiaoxue",
    "Xiaoyan",
    "Xiaoying",
    "Xin",
    "Xinran",
    "Xinyi",
    "Xiu",
    "Xiulan",
    "Xiuying",
    "Xu",
    "Xuan",
    "Xuanxuan",
    "Xue",
    "Yajie",
    "Yan",
    "Yanfen",
    "Yang",
    "Yanhua",
    "Yanli",
    "Yao",
    "Ye",
    "Yi",
    "Ying",
    "Yinghua",
    "Yingying",
    "Yingzi",
    "Yiyi",
    "Yong",
    "Yonghong",
    "You",
    "Yu",
    "Yuan",
    "Yuanli",
    "Yuanyuan",
    "Yue",
    "Yumei",
    "Yun",
    "Yuqing",
    "Zeng",
    "Zhan",
    "Zhang",
    "Zhao",
    "Zhen",
    "Zheng",
    "Zhenzhen",
    "Zhi",
    "Zhong",
    "Zhou",
    "Zhu",
    "Zhuang",
    "Zhuo",
    "Zi",
    "Zong",
    "Zuo",
]

male_names = [
    "Bao",
    "Bing",
    "Bo",
    "Cai",
    "Cao",
    "Cen",
    "Chai",
    "Chao",
    "Chen",
    "Cheng",
    "Chu",
    "Cui",
    "Dai",
    "Dan",
    "Deng",
    "Ding",
    "Dong",
    "Du",
    "Duan",
    "Fan",
    "Fang",
    "Feng",
    "Fu",
    "Gan",
    "Gao",
    "Ge",
    "Gong",
    "Gu",
    "Guan",
    "Gui",
    "Guo",
    "Han",
    "Hao",
    "He",
    "Heng",
    "Hong",
    "Hou",
    "Hu",
    "Hua",
    "Huang",
    "Hui",
    "Ji",
    "Jian",
    "Jiang",
    "Jiao",
    "Jin",
    "Jing",
    "Jiu",
    "Ju",
    "Jun",
    "Kang",
    "Ke",
    "Kong",
    "Lai",
    "Lei",
    "Li",
    "Lian",
    "Liang",
    "Liao",
    "Lin",
    "Ling",
    "Liu",
    "Long",
    "Lu",
    "Luan",
    "Lü",
    "Ma",
    "Mai",
    "Mao",
    "Mei",
    "Meng",
    "Mi",
    "Miao",
    "Ming",
    "Mo",
    "Nan",
    "Nian",
    "Ning",
    "Nuo",
    "Pai",
    "Pan",
    "Ping",
    "Po",
    "Pu",
    "Qi",
    "Qian",
    "Qiang",
    "Qin",
    "Qing",
    "Qiu",
    "Qu",
    "Quan",
    "Ren",
    "Rong",
    "Ru",
    "Rui",
    "Run",
    "Sai",
    "Shan",
    "Shang",
    "Shao",
    "Shen",
    "Sheng",
    "Shi",
    "Shou",
    "Shu",
    "Si",
    "Song",
    "Su",
    "Sui",
    "Sun",
    "Tai",
    "Tang",
    "Tao",
    "Tian",
    "Tong",
    "Tu",
    "Wan",
    "Wang",
    "Wei",
    "Wen",
    "Wu",
    "Xi",
    "Xian",
    "Xiang",
    "Xiao",
    "Xin",
    "Xing",
    "Xiu",
    "Xu",
    "Xuan",
    "Xue",
    "Yang",
    "Yao",
    "Ye",
    "Yi",
    "Yin",
    "Ying",
    "Yong",
    "You",
    "Yu",
    "Yuan",
    "Yue",
    "Yun",
    "Zeng",
    "Zhang",
    "Zhao",
    "Zhen",
    "Zheng",
    "Zhi",
    "Zhong",
    "Zhou",
    "Zhu",
    "Zhuan",
    "Zhuo",
    "Zi",
    "Zong",
    "Zu",
]

surnames = [
    "Bai",
    "Bo",
    "Cao",
    "Chen",
    "Chi",
    "Chu",
    "Cui",
    "Dai",
    "Ding",
    "Dong",
    "Du",
    "Duan",
    "Fan",
    "Fang",
    "Feng",
    "Fu",
    "Gao",
    "Ge",
    "Gong",
    "Gu",
    "Guan",
    "Gui",
    "Han",
    "Hao",
    "He",
    "Hong",
    "Hu",
    "Hua",
    "Huang",
    "Hui",
    "Ji",
    "Jian",
    "Jiang",
    "Jiao",
    "Jin",
    "Jing",
    "Jiu",
    "Kang",
    "Ke",
    "Kong",
    "Kuang",
    "Lei",
    "Li",
    "Lian",
    "Liang",
    "Lin",
    "Ling",
    "Liu",
    "Long",
    "Lu",
    "Luan",
    "Lü",
    "Ma",
    "Mai",
    "Meng",
    "Mi",
    "Miao",
    "Ming",
    "Mo",
    "Mu",
    "Nan",
    "Ni",
    "Ning",
    "Pan",
    "Peng",
    "Ping",
    "Pu",
    "Qian",
    "Qiao",
    "Qing",
    "Qiu",
    "Qu",
    "Ren",
    "Rong",
    "Ru",
    "Shan",
    "Shang",
    "Shen",
    "Shi",
    "Shu",
    "Si",
    "Song",
    "Sun",
    "Suo",
    "Tai",
    "Tang",
    "Tao",
    "Tian",
    "Tong",
    "Wang",
    "Wei",
    "Wen",
    "Wu",
    "Xi",
    "Xia",
    "Xiao",
    "Xin",
    "Xing",
    "Xiong",
    "Xiu",
    "Xu",
    "Xue",
    "Yan",
    "Yang",
    "Yao",
    "Ye",
    "Yi",
    "Yin",
    "Ying",
    "You",
    "Yu",
    "Yuan",
    "Yue",
    "Yun",
    "Zeng",
    "Zhang",
    "Zhao",
    "Zhen",
    "Zheng",
    "Zhi",
    "Zhong",
    "Zhou",
    "Zhu",
    "Zhuang",
    "Zi",
    "Zong",
    "Zou",
]



female_prefix = [
    "ael",
    "al",
    "an",
    "ar",
    "cal",
    "dael",
    "el",
    "er",
    "fae",
    "fal",
    "fi",
    "gal",
    "gil",
    "glor",
    "hal",
    "ia",
    "id",
    "il",
    "im",
    "in",
    "laer",
    "lan",
    "leg",
    "li",
    "lind",
    "lith",
    "lor",
    "mae",
    "mel",
    "na",
    "nar",
    "nen",
    "ner",
    "or",
    "pe",
    "ran",
    "rhov",
    "sae",
    "saer",
    "se",
    "sil",
    "ta",
    "thal",
    "thar",
    "thing",
    "ti",
    "tir",
    "val",
    "ví",
    "yar",
    "zeph",
    "zim",
]

female_suffix = [
    "á",
    "ë",
    "í",
    "ír",
    "ís",
    "ith",
    "lá",
    "lé",
    "liël",
    "lís",
    "lith",
    "lyn",
    "má",
    "më",
    "mí",
    "ná",
    "në",
    "niël",
    "nis",
    "nith",
    "nyá",
    "rá",
    "ré",
    "riël",
    "ris",
    "rith",
    "ryá",
    "sä",
    "së",
    "siél",
    "sis",
    "sith",
    "stá",
    "thél",
    "theá",
    "thée",
    "thiël",
    "this",
    "thith",
    "vyl",
    "wén",
    "wiel",
    "wis",
    "withë",
    "yá",
    "yë",
    "yra",
    "ysë",
]

male_prefix = [
    "aeg",
    "aer",
    "am",
    "an",
    "ar",
    "bar",
    "ber",
    "cal",
    "cel",
    "cor",
    "dan",
    "dar",
    "den",
    "dor",
    "el",
    "em",
    "en",
    "er",
    "fal",
    "fer",
    "gal",
    "gar",
    "gil",
    "glor",
    "hal",
    "har",
    "hel",
    "her",
    "iath",
    "im",
    "in",
    "ir",
    "lam",
    "lar",
    "len",
    "lin",
    "lor",
    "mel",
    "men",
    "mir",
    "nem",
    "ner",
    "nim",
    "nor",
    "ol",
    "or",
    "rad",
    "ral",
    "ran",
    "rel",
    "rim",
    "ron",
    "sam",
    "san",
    "ser",
    "sil",
    "sin",
    "sor",
    "tan",
    "tar",
    "tel",
    "thor",
    "tom",
    "tor",
    "ul",
    "ur",
    "val",
    "var",
    "vén",
    "ver",
    "wil",
    "win",
    "wis",
    "yam",
    "yar",
    "ÿer",
    "yin",
    "yol",
]

male_suffix = [
    "ad",
    "aél",
    "an",
    "and",
    "ar",
    "ard",
    "as",
    "ath",
    "énd",
    "ër",
    "ern",
    "eth",
    "il",
    "in",
    "ind",
    "ion",
    "ir",
    "is",
    "ith",
    "lad",
    "läs",
    "lin",
    "lo",
    "lon",
    "or",
    "orn",
    "os",
    "rad",
    "rän",
    "ras",
    "rath",
    "rin",
    "ron",
    "ros",
    "rth",
    "th",
    "thir",
    "thor",
    "únd",
    "úr",
    "us",
    "win",
    "ynd",
    "yon",
    "ÿth",
]

surname_syllables = [
    "ael",
    "al",
    "an",
    "ar",
    "cal",
    "dael",
    "ël",
    "er",
    "fae",
    "fal",
    "fi",
    "gal",
    "gil",
    "glor",
    "hal",
    "ia",
    "id",
    "il",
    "im",
    "in",
    "laér",
    "lan",
    "leg",
    "li",
    "lind",
    "lith",
    "lor",
    "mae",
    "mel",
    "ne",
    "ner",
    "nén",
    "ner",
    "or",
    "pe",
    "ran",
    "rhöv",
    "sae",
    "sae",
    "se",
    "sil",
    "ta",
    "thal",
    "thar",
    "thing",
    "ti",
    "tir",
    "val",
    "vi",
    "yar",
    "zah",
    "zim",
]

female_names = [
    "Aerandir",
    "Aeranduil",
    "Aerandur",
    "Aerandë",
    "Aerendil",
    "Alcanna",
    "Almena",
    "Amarthiel",
    "Anaria",
    "Anorwen",
    "Aranel",
    "Arasinya",
    "Arianeth",
    "Arieneth",
    "Arieth",
    "Arilwen",
    "Arwenia",
    "Avelera",
    "Avendil",
    "Calanthe",
    "Calathiel",
    "Celebeth",
    "Celestria",
    "Cirael",
    "Ciriana",
    "Danathiel",
    "Danoviel",
    "Darien",
    "Dawnstar",
    "Elariel",
    "Elathir",
    "Elenwë",
    "Elindra",
    "Elionor",
    "Elissia",
    "Elora",
    "Elowen",
    "Elthiriel",
    "Elwing",
    "Emerwen",
    "Endellion",
    "Eolande",
    "Erandis",
    "Erendis",
    "Erlindë",
    "Ermalinde",
    "Esteldín",
    "Estrith",
    "Evangeline",
    "Evanya",
    "Faelwen",
    "Faerindel",
    "Fairwen",
    "Firiel",
    "Galadhrim",
    "Galadriel",
    "Galadwen",
    "Galanwë",
    "Galdrielle",
    "Galdwen",
    "Gariel",
    "Gedriel",
    "Gilmith",
    "Glorfindel",
    "Gwindor",
    "Halethriel",
    "Helengil",
    "Hithlindë",
    "Hithrael",
    "Idril",
    "Idrilas",
    "Ithildin",
    "Ithilwen",
    "Ivriniel",
    "Lalwendë",
    "Lhûthien",
    "Liriel",
    "Lómelindi",
    "Maeglin",
    "Maelwë",
    "Maiarwen",
    "Maiel",
    "Melian",
    "Meril",
    "Merilwen",
    "Morwen",
    "Máeldir",
    "Mírwen",
    "Narwindë",
    "Nellas",
    "Nenloth",
    "Nimrodel",
    "Nirneth",
    "Noralindë",
    "Nólemië",
    "Orodreth",
    "Perelin",
    "Píriel",
    "Ravendis",
    "Rhawiel",
    "Rinniell",
    "Roselindë",
    "Ríëndel",
    "Saeldil",
    "Saelindë",
    "Saeros",
    "Salandria",
    "Sarethiel",
    "Sauriel",
    "Selenia",
    "Sereneth",
    "Shalindra",
    "Silmarwen",
    "Sírdathiel",
    "Sírindë",
    "Sírwen",
    "Talindra",
    "Thalion",
    "Tinúviel",
    "Undómë",
    "Valandil",
    "Vanië",
    "Vanwë",
    "Vanyarin",
    "Yavanna",
    "Yavannamírë",
    "Yavannië",
    "Yúvathië",
    "Zíriath",
]

male_names = [
    "Aegnor",
    "Aeran",
    "Aerandir",
    "Alarion",
    "Aldaron",
    "Almarion",
    "Amalion",
    "Amarael",
    "Amathar",
    "Amlach",
    "Anarion",
    "Anduil",
    "Angrod",
    "Anorion",
    "Aradhel",
    "Arador",
    "Aragorn",
    "Aranarth",
    "Arandur",
    "Aranion",
    "Arathorn",
    "Aravel",
    "Aravir",
    "Aredhel",
    "Argon",
    "Arveleg",
    "Arwen",
    "Asfaloth",
    "Asgaloth",
    "Aulendil",
    "Azaghal",
    "Balion",
    "Baragund",
    "Barahir",
    "Bard",
    "Belegon",
    "Belegorn",
    "Beren",
    "Boromir",
    "Bregolas",
    "Caladon",
    "Calenon",
    "Calion",
    "Celebrimbor",
    "Celedorn",
    "Cirdan",
    "Cirelind",
    "Curufin",
    "Daelion",
    "Daeron",
    "Darian",
    "Dior",
    "Dorion",
    "Duilin",
    "Earendur",
    "Ecthelion",
    "Egalmoth",
    "Eladion",
    "Eldacar",
    "Eldamir",
    "Eldaron",
    "Eledhel",
    "Elendil",
    "Elendor",
    "Elendur",
    "Elenion",
    "Elgalad",
    "Elithil",
    "Elladan",
    "Elorand",
    "Elorian",
    "Elrindel",
    "Elrion",
    "Elrond",
    "Elros",
    "Eol",
    "Eonwe",
    "Eorl",
    "Erestel",
    "Erestor",
    "Erkenbrand",
    "Eruhantalë",
    "Eärendil",
    "Faelindir",
    "Faelion",
    "Faladon",
    "Falmir",
    "Faramir",
    "Felagund",
    "Finarfin",
    "Finarion",
    "Findegil",
    "Finduilas",
    "Fingolfin",
    "Fingon",
    "Finrod",
    "Galadhel",
    "Galadriel",
    "Galandir",
    "Galdor",
    "Galion",
    "Gil-galad",
    "Gildor",
    "Gilion",
    "Gimli",
    "Glorandir",
    "Glorfindel",
    "Gwindor",
    "Haldir",
    "Haldirion",
    "Haldon",
    "Halfling",
    "Hallas",
    "Halmir",
    "Hathaldir",
    "Helm",
    "Huan",
    "Húrin",
    "Idril",
    "Imrahil",
    "Indor",
    "Ingwë",
    "Irime",
    "Isildur",
    "Ithilion",
    "Laerion",
    "Landion",
    "Legolas",
    "Lendor",
    "Lirandil",
    "Mablung",
    "Maedhros",
    "Maeglin",
    "Maegon",
    "Maelon",
    "Maendir",
    "Manwë",
    "Melian",
    "Mithrandir",
    "Mîm",
    "Narion",
    "Neldor",
    "Nimloth",
    "Olorin",
    "Olwë",
    "Orandil",
    "Orc",
    "Oromë",
    "Pippin",
    "Radagast",
    "Ralion",
    "Rindon",
    "Saelion",
    "Saeros",
    "Samwise",
    "Saruman",
    "Seldor",
    "Shadowfax",
    "Silindor",
    "Smaug",
    "Taeros",
    "Talandor",
    "Taurion",
    "Thalion",
    "Thalos",
    "Thandir",
    "Thingol",
    "Thorin",
    "Thranduil",
    "Théoden",
    "Tinor",
    "Tinúviel",
    "Tirion",
    "Tuor",
    "Turgon",
    "Ungoliant",
    "Valandil",
    "Valandur",
    "Valarion",
    "Vanyar",
    "Varandil",
    "Varda",
    "Varion",
    "Varyon",
    "Vingil",
    "Voronwe",
    "Voronwë",
    "Yavanna",
]

surnames = [
    "Acalor",
    "Acarnor",
    "Aelindë",
    "Aerendil",
    "Alaraith",
    "Aldorin",
    "Amastë",
    "Anarion",
    "Angolë",
    "Aralion",
    "Arandor",
    "Arathir",
    "Ardalas",
    "Ardilas",
    "Ariandel",
    "Arnoron",
    "Ascarion",
    "Astaldor",
    "Astoron",
    "Belarion",
    "Belarond",
    "Boromir",
    "Borondir",
    "Brenornë",
    "Caerin",
    "Caerion",
    "Caladrel",
    "Calandil",
    "Calithil",
    "Carnadon",
    "Carnador",
    "Celador",
    "Celeborn",
    "Cirdanion",
    "Cirdanor",
    "Cirya",
    "Cúaladir",
    "Cúaldor",
    "Cúrion",
    "Dírhael",
    "Dúrinnë",
    "Eldaron",
    "Elendor",
    "Elessindë",
    "Elgalad",
    "Elgarion",
    "Elnaril",
    "Elnarion",
    "Elorwen",
    "Enethril",
    "Enthil",
    "Enyandil",
    "Faelith",
    "Faenor",
    "Falathan",
    "Faldorin",
    "Falrindil",
    "Finraen",
    "Finroth",
    "Galathil",
    "Galathor",
    "Galdorin",
    "Galdorion",
    "Galithor",
    "Glarion",
    "Glorinor",
    "Haladan",
    "Haladir",
    "Halindir",
    "Hanarë",
    "Hathalon",
    "Hatharion",
    "Hilindë",
    "Idhrendil",
    "Idhrendor",
    "Idhrinor",
    "Ildirion",
    "Ildorion",
    "Ilendil",
    "Imrahil",
    "Imrathor",
    "Inglorion",
    "Innarë",
    "Lindalas",
    "Lindor",
    "Lindorin",
    "Lithariel",
    "Lithilas",
    "Lithilorn",
    "Lorfindel",
    "Lorien",
    "Lorindil",
    "Maegdor",
    "Maegdorin",
    "Maeglin",
    "Melorian",
    "Melorion",
    "Melrondë",
    "Narothir",
    "Narothor",
    "Narwindë",
    "Nimloth",
    "Nimrion",
    "Nimrith",
    "Noraelin",
    "Nórin",
    "Nórion",
    "Orandil",
    "Orandor",
    "Orinor",
    "Peralin",
    "Peregrin",
    "Ranthalas",
    "Rhovandir",
    "Rhovendor",
    "Rhovendur",
    "Rivendal",
    "Saerindë",
    "Saeros",
    "Saldaron",
    "Saldorion",
    "Silgadil",
    "Silgarion",
    "Silrion",
    "Talathor",
    "Talathorin",
    "Talindra",
    "Thalassë",
    "Thandor",
    "Thandorin",
    "Tharrë",
    "Thingolion",
    "Thorondil",
    "Tirithorn",
    "Valandor",
    "Valandorin",
    "Valendil",
    "Virendor",
    "Virendorin",
    "Vírelindë",
    "Yaralan",
    "Yaralon",
    "Yarenthir",
    "Zephiron",
    "Zephiroth",
    "Zephyrnir",
    "Zimranor",
    "Zimrathil",
    "Zimrathor",
]
